Class: Google::Apis::RetailV2::GoogleCloudRetailV2CompleteQueryResponseCompletionResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb

Overview

Resource that represents completion results.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2CompleteQueryResponseCompletionResult

Returns a new instance of GoogleCloudRetailV2CompleteQueryResponseCompletionResult.



1216
1217
1218
# File 'lib/google/apis/retail_v2/classes.rb', line 1216

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attributesHash<String,Google::Apis::RetailV2::GoogleCloudRetailV2CustomAttribute>

Custom attributes for the suggestion term. * For user-data, the attributes are additional custom attributes ingested through BigQuery. * For cloud- retail, the attributes are product attributes generated by Cloud Retail. It requires UserEvent.product_details is imported properly. Corresponds to the JSON property attributes



1209
1210
1211
# File 'lib/google/apis/retail_v2/classes.rb', line 1209

def attributes
  @attributes
end

#suggestionString

The suggestion for the query. Corresponds to the JSON property suggestion

Returns:

  • (String)


1214
1215
1216
# File 'lib/google/apis/retail_v2/classes.rb', line 1214

def suggestion
  @suggestion
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1221
1222
1223
1224
# File 'lib/google/apis/retail_v2/classes.rb', line 1221

def update!(**args)
  @attributes = args[:attributes] if args.key?(:attributes)
  @suggestion = args[:suggestion] if args.key?(:suggestion)
end