Class: Google::Apis::RetailV2::GoogleCloudRetailV2CompletionConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb

Overview

Catalog level autocomplete config for customers to customize autocomplete feature's settings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2CompletionConfig

Returns a new instance of GoogleCloudRetailV2CompletionConfig.



1325
1326
1327
# File 'lib/google/apis/retail_v2/classes.rb', line 1325

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowlist_input_configGoogle::Apis::RetailV2::GoogleCloudRetailV2CompletionDataInputConfig

The input config source for completion data. Corresponds to the JSON property allowlistInputConfig



1254
1255
1256
# File 'lib/google/apis/retail_v2/classes.rb', line 1254

def allowlist_input_config
  @allowlist_input_config
end

#auto_learningBoolean Also known as: auto_learning?

If set to true, the auto learning function is enabled. Auto learning uses user data to generate suggestions using ML techniques. Default value is false. Only after enabling auto learning can users use cloud-retail data in CompleteQueryRequest. Corresponds to the JSON property autoLearning

Returns:

  • (Boolean)


1262
1263
1264
# File 'lib/google/apis/retail_v2/classes.rb', line 1262

def auto_learning
  @auto_learning
end

#denylist_input_configGoogle::Apis::RetailV2::GoogleCloudRetailV2CompletionDataInputConfig

The input config source for completion data. Corresponds to the JSON property denylistInputConfig



1268
1269
1270
# File 'lib/google/apis/retail_v2/classes.rb', line 1268

def denylist_input_config
  @denylist_input_config
end

#last_allowlist_import_operationString

Output only. Name of the LRO corresponding to the latest allowlist import. Can use GetOperation API to retrieve the latest state of the Long Running Operation. Corresponds to the JSON property lastAllowlistImportOperation

Returns:

  • (String)


1275
1276
1277
# File 'lib/google/apis/retail_v2/classes.rb', line 1275

def last_allowlist_import_operation
  @last_allowlist_import_operation
end

#last_denylist_import_operationString

Output only. Name of the LRO corresponding to the latest denylist import. Can use GetOperation API to retrieve the latest state of the Long Running Operation. Corresponds to the JSON property lastDenylistImportOperation

Returns:

  • (String)


1282
1283
1284
# File 'lib/google/apis/retail_v2/classes.rb', line 1282

def last_denylist_import_operation
  @last_denylist_import_operation
end

#last_suggestions_import_operationString

Output only. Name of the LRO corresponding to the latest suggestion terms list import. Can use GetOperation API method to retrieve the latest state of the Long Running Operation. Corresponds to the JSON property lastSuggestionsImportOperation

Returns:

  • (String)


1289
1290
1291
# File 'lib/google/apis/retail_v2/classes.rb', line 1289

def last_suggestions_import_operation
  @last_suggestions_import_operation
end

#matching_orderString

Specifies the matching order for autocomplete suggestions, e.g., a query consisting of 'sh' with 'out-of-order' specified would suggest "women's shoes", whereas a query of 'red s' with 'exact-prefix' specified would suggest "red shoes". Currently supported values: * 'out-of-order' * 'exact-prefix' Default value: 'exact-prefix'. Corresponds to the JSON property matchingOrder

Returns:

  • (String)


1298
1299
1300
# File 'lib/google/apis/retail_v2/classes.rb', line 1298

def matching_order
  @matching_order
end

#max_suggestionsFixnum

The maximum number of autocomplete suggestions returned per term. Default value is 20. If left unset or set to 0, then will fallback to default value. Value range is 1 to 20. Corresponds to the JSON property maxSuggestions

Returns:

  • (Fixnum)


1305
1306
1307
# File 'lib/google/apis/retail_v2/classes.rb', line 1305

def max_suggestions
  @max_suggestions
end

#min_prefix_lengthFixnum

The minimum number of characters needed to be typed in order to get suggestions. Default value is 2. If left unset or set to 0, then will fallback to default value. Value range is 1 to 20. Corresponds to the JSON property minPrefixLength

Returns:

  • (Fixnum)


1312
1313
1314
# File 'lib/google/apis/retail_v2/classes.rb', line 1312

def min_prefix_length
  @min_prefix_length
end

#nameString

Required. Immutable. Fully qualified name projects/*/locations/*/catalogs/*/ completionConfig Corresponds to the JSON property name

Returns:

  • (String)


1318
1319
1320
# File 'lib/google/apis/retail_v2/classes.rb', line 1318

def name
  @name
end

#suggestions_input_configGoogle::Apis::RetailV2::GoogleCloudRetailV2CompletionDataInputConfig

The input config source for completion data. Corresponds to the JSON property suggestionsInputConfig



1323
1324
1325
# File 'lib/google/apis/retail_v2/classes.rb', line 1323

def suggestions_input_config
  @suggestions_input_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
1342
# File 'lib/google/apis/retail_v2/classes.rb', line 1330

def update!(**args)
  @allowlist_input_config = args[:allowlist_input_config] if args.key?(:allowlist_input_config)
  @auto_learning = args[:auto_learning] if args.key?(:auto_learning)
  @denylist_input_config = args[:denylist_input_config] if args.key?(:denylist_input_config)
  @last_allowlist_import_operation = args[:last_allowlist_import_operation] if args.key?(:last_allowlist_import_operation)
  @last_denylist_import_operation = args[:last_denylist_import_operation] if args.key?(:last_denylist_import_operation)
  @last_suggestions_import_operation = args[:last_suggestions_import_operation] if args.key?(:last_suggestions_import_operation)
  @matching_order = args[:matching_order] if args.key?(:matching_order)
  @max_suggestions = args[:max_suggestions] if args.key?(:max_suggestions)
  @min_prefix_length = args[:min_prefix_length] if args.key?(:min_prefix_length)
  @name = args[:name] if args.key?(:name)
  @suggestions_input_config = args[:suggestions_input_config] if args.key?(:suggestions_input_config)
end