Class: Google::Apis::RetailV2::GoogleCloudRetailV2Condition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb

Overview

Metadata that is used to define a condition that triggers an action. A valid condition must specify at least one of 'query_terms' or 'products_filter'. If multiple fields are specified, the condition is met if all the fields are satisfied e.g. if a set of query terms and product_filter are set, then only items matching the product_filter for requests with a query matching the query terms wil get boosted.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2Condition

Returns a new instance of GoogleCloudRetailV2Condition.



1425
1426
1427
# File 'lib/google/apis/retail_v2/classes.rb', line 1425

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#active_time_rangeArray<Google::Apis::RetailV2::GoogleCloudRetailV2ConditionTimeRange>

Range of time(s) specifying when Condition is active. Condition true if any time range matches. Corresponds to the JSON property activeTimeRange



1410
1411
1412
# File 'lib/google/apis/retail_v2/classes.rb', line 1410

def active_time_range
  @active_time_range
end

#page_categoriesArray<String>

Used to support browse uses cases. A list (up to 10 entries) of categories or departments. The format should be the same as UserEvent.page_categories; Corresponds to the JSON property pageCategories

Returns:

  • (Array<String>)


1416
1417
1418
# File 'lib/google/apis/retail_v2/classes.rb', line 1416

def page_categories
  @page_categories
end

#query_termsArray<Google::Apis::RetailV2::GoogleCloudRetailV2ConditionQueryTerm>

A list (up to 10 entries) of terms to match the query on. If not specified, match all queries. If many query terms are specified, the condition is matched if any of the terms is a match (i.e. using the OR operator). Corresponds to the JSON property queryTerms



1423
1424
1425
# File 'lib/google/apis/retail_v2/classes.rb', line 1423

def query_terms
  @query_terms
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1430
1431
1432
1433
1434
# File 'lib/google/apis/retail_v2/classes.rb', line 1430

def update!(**args)
  @active_time_range = args[:active_time_range] if args.key?(:active_time_range)
  @page_categories = args[:page_categories] if args.key?(:page_categories)
  @query_terms = args[:query_terms] if args.key?(:query_terms)
end