Class: Google::Apis::RetailV2::GoogleCloudRetailV2ConversationalSearchCustomizationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb

Overview

The public proto to represent the conversational search customization config. It will be converted to the internal proto in the backend.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2ConversationalSearchCustomizationConfig

Returns a new instance of GoogleCloudRetailV2ConversationalSearchCustomizationConfig.



1578
1579
1580
# File 'lib/google/apis/retail_v2/classes.rb', line 1578

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#catalogString

Required. Resource name of the catalog. Format: projects/project/locations/ location/catalogs/catalog Corresponds to the JSON property catalog

Returns:

  • (String)


1564
1565
1566
# File 'lib/google/apis/retail_v2/classes.rb', line 1564

def catalog
  @catalog
end

#intent_classification_configGoogle::Apis::RetailV2::GoogleCloudRetailV2IntentClassificationConfig

The public proto to represent the intent classification config. It will be converted to the internal proto in the backend. Corresponds to the JSON property intentClassificationConfig



1570
1571
1572
# File 'lib/google/apis/retail_v2/classes.rb', line 1570

def intent_classification_config
  @intent_classification_config
end

#retailer_display_nameString

Optional. The retailer's display name that could be used in our LLM answers. Example - "Google" Corresponds to the JSON property retailerDisplayName

Returns:

  • (String)


1576
1577
1578
# File 'lib/google/apis/retail_v2/classes.rb', line 1576

def retailer_display_name
  @retailer_display_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1583
1584
1585
1586
1587
# File 'lib/google/apis/retail_v2/classes.rb', line 1583

def update!(**args)
  @catalog = args[:catalog] if args.key?(:catalog)
  @intent_classification_config = args[:intent_classification_config] if args.key?(:intent_classification_config)
  @retailer_display_name = args[:retailer_display_name] if args.key?(:retailer_display_name)
end