Class: Google::Apis::RetailV2::GoogleCloudRetailV2ConversationalSearchRequestSearchParams

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb

Overview

Search parameters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2ConversationalSearchRequestSearchParams

Returns a new instance of GoogleCloudRetailV2ConversationalSearchRequestSearchParams.



1756
1757
1758
# File 'lib/google/apis/retail_v2/classes.rb', line 1756

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#boost_specGoogle::Apis::RetailV2::GoogleCloudRetailV2SearchRequestBoostSpec

Boost specification to boost certain items. Corresponds to the JSON property boostSpec



1736
1737
1738
# File 'lib/google/apis/retail_v2/classes.rb', line 1736

def boost_spec
  @boost_spec
end

#canonical_filterString

Optional. The canonical filter string to restrict search results. The syntax of the canonical filter string is the same as SearchRequest.canonical_filter. Corresponds to the JSON property canonicalFilter

Returns:

  • (String)


1742
1743
1744
# File 'lib/google/apis/retail_v2/classes.rb', line 1742

def canonical_filter
  @canonical_filter
end

#filterString

Optional. The filter string to restrict search results. The syntax of the filter string is the same as SearchRequest.filter. Corresponds to the JSON property filter

Returns:

  • (String)


1748
1749
1750
# File 'lib/google/apis/retail_v2/classes.rb', line 1748

def filter
  @filter
end

#sort_byString

Optional. The sort string to specify the sorting of search results. The syntax of the sort string is the same as SearchRequest.order_by. Corresponds to the JSON property sortBy

Returns:

  • (String)


1754
1755
1756
# File 'lib/google/apis/retail_v2/classes.rb', line 1754

def sort_by
  @sort_by
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1761
1762
1763
1764
1765
1766
# File 'lib/google/apis/retail_v2/classes.rb', line 1761

def update!(**args)
  @boost_spec = args[:boost_spec] if args.key?(:boost_spec)
  @canonical_filter = args[:canonical_filter] if args.key?(:canonical_filter)
  @filter = args[:filter] if args.key?(:filter)
  @sort_by = args[:sort_by] if args.key?(:sort_by)
end