Class: Google::Apis::RetailV2::GoogleCloudRetailV2ConversationalSearchRequestUserAnswer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb

Overview

This field specifies the current user answer during the conversational filtering search. This can be either user selected from suggested answers or user input plain text.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2ConversationalSearchRequestUserAnswer

Returns a new instance of GoogleCloudRetailV2ConversationalSearchRequestUserAnswer.



1786
1787
1788
# File 'lib/google/apis/retail_v2/classes.rb', line 1786

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#selected_answerGoogle::Apis::RetailV2::GoogleCloudRetailV2ConversationalSearchRequestUserAnswerSelectedAnswer

This field specifies the selected answers during the conversational search. Corresponds to the JSON property selectedAnswer



1778
1779
1780
# File 'lib/google/apis/retail_v2/classes.rb', line 1778

def selected_answer
  @selected_answer
end

#text_answerString

This field specifies the incremental input text from the user during the conversational search. Corresponds to the JSON property textAnswer

Returns:

  • (String)


1784
1785
1786
# File 'lib/google/apis/retail_v2/classes.rb', line 1784

def text_answer
  @text_answer
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1791
1792
1793
1794
# File 'lib/google/apis/retail_v2/classes.rb', line 1791

def update!(**args)
  @selected_answer = args[:selected_answer] if args.key?(:selected_answer)
  @text_answer = args[:text_answer] if args.key?(:text_answer)
end