Class: Google::Apis::RetailV2::GoogleCloudRetailV2CustomAttribute

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb

Overview

A custom attribute that is not explicitly modeled in Product.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2CustomAttribute

Returns a new instance of GoogleCloudRetailV2CustomAttribute.



2064
2065
2066
# File 'lib/google/apis/retail_v2/classes.rb', line 2064

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#indexableBoolean Also known as: indexable?

This field is normally ignored unless AttributesConfig.attribute_config_level of the Catalog is set to the deprecated 'PRODUCT_LEVEL_ATTRIBUTE_CONFIG' mode. For information about product-level attribute configuration, see Configuration modes. If true, custom attribute values are indexed, so that they can be filtered, faceted or boosted in SearchService.Search. This field is ignored in a UserEvent. See SearchRequest.filter, SearchRequest.facet_specs and SearchRequest.boost_spec for more details. Corresponds to the JSON property indexable

Returns:

  • (Boolean)


2034
2035
2036
# File 'lib/google/apis/retail_v2/classes.rb', line 2034

def indexable
  @indexable
end

#numbersArray<Float>

The numerical values of this custom attribute. For example, [2.3, 15.4] when the key is "lengths_cm". Exactly one of text or numbers should be set. Otherwise, an INVALID_ARGUMENT error is returned. Corresponds to the JSON property numbers

Returns:

  • (Array<Float>)


2042
2043
2044
# File 'lib/google/apis/retail_v2/classes.rb', line 2042

def numbers
  @numbers
end

#searchableBoolean Also known as: searchable?

This field is normally ignored unless AttributesConfig.attribute_config_level of the Catalog is set to the deprecated 'PRODUCT_LEVEL_ATTRIBUTE_CONFIG' mode. For information about product-level attribute configuration, see Configuration modes. If true, custom attribute values are searchable by text queries in SearchService.Search. This field is ignored in a UserEvent. Only set if type text is set. Otherwise, a INVALID_ARGUMENT error is returned. Corresponds to the JSON property searchable

Returns:

  • (Boolean)


2053
2054
2055
# File 'lib/google/apis/retail_v2/classes.rb', line 2053

def searchable
  @searchable
end

#textArray<String>

The textual values of this custom attribute. For example, ["yellow", "green"] when the key is "color". Empty string is not allowed. Otherwise, an INVALID_ARGUMENT error is returned. Exactly one of text or numbers should be set. Otherwise, an INVALID_ARGUMENT error is returned. Corresponds to the JSON property text

Returns:

  • (Array<String>)


2062
2063
2064
# File 'lib/google/apis/retail_v2/classes.rb', line 2062

def text
  @text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2069
2070
2071
2072
2073
2074
# File 'lib/google/apis/retail_v2/classes.rb', line 2069

def update!(**args)
  @indexable = args[:indexable] if args.key?(:indexable)
  @numbers = args[:numbers] if args.key?(:numbers)
  @searchable = args[:searchable] if args.key?(:searchable)
  @text = args[:text] if args.key?(:text)
end