Class: Google::Apis::RetailV2::GoogleCloudRetailV2ImportProductsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb

Overview

Request message for Import methods.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2ImportProductsRequest

Returns a new instance of GoogleCloudRetailV2ImportProductsRequest.



2697
2698
2699
# File 'lib/google/apis/retail_v2/classes.rb', line 2697

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errors_configGoogle::Apis::RetailV2::GoogleCloudRetailV2ImportErrorsConfig

Configuration of destination for Import related errors. Corresponds to the JSON property errorsConfig



2659
2660
2661
# File 'lib/google/apis/retail_v2/classes.rb', line 2659

def errors_config
  @errors_config
end

#input_configGoogle::Apis::RetailV2::GoogleCloudRetailV2ProductInputConfig

The input config source for products. Corresponds to the JSON property inputConfig



2664
2665
2666
# File 'lib/google/apis/retail_v2/classes.rb', line 2664

def input_config
  @input_config
end

#notification_pubsub_topicString

Full Pub/Sub topic name for receiving notification. If this field is set, when the import is finished, a notification is sent to specified Pub/Sub topic. The message data is JSON string of a Operation. Format of the Pub/Sub topic is projects/project/topics/topic`. It has to be within the same project as ImportProductsRequest.parent. Make sure that bothcloud-retail-customer-data- access@system.gserviceaccount.comandservice-@gcp-sa-retail.iam. gserviceaccount.comhave thepubsub.topics.publishIAM permission on the topic. Only supported when ImportProductsRequest.reconciliation_mode is set to FULL. Corresponds to the JSON propertynotificationPubsubTopic`

Returns:

  • (String)


2677
2678
2679
# File 'lib/google/apis/retail_v2/classes.rb', line 2677

def notification_pubsub_topic
  @notification_pubsub_topic
end

#reconciliation_modeString

The mode of reconciliation between existing products and the products to be imported. Defaults to ReconciliationMode.INCREMENTAL. Corresponds to the JSON property reconciliationMode

Returns:

  • (String)


2683
2684
2685
# File 'lib/google/apis/retail_v2/classes.rb', line 2683

def reconciliation_mode
  @reconciliation_mode
end

#request_idString

Deprecated. This field has no effect. Corresponds to the JSON property requestId

Returns:

  • (String)


2688
2689
2690
# File 'lib/google/apis/retail_v2/classes.rb', line 2688

def request_id
  @request_id
end

#update_maskString

Indicates which fields in the provided imported products to update. If not set, all fields are updated. If provided, only the existing product fields are updated. Missing products will not be created. Corresponds to the JSON property updateMask

Returns:

  • (String)


2695
2696
2697
# File 'lib/google/apis/retail_v2/classes.rb', line 2695

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2702
2703
2704
2705
2706
2707
2708
2709
# File 'lib/google/apis/retail_v2/classes.rb', line 2702

def update!(**args)
  @errors_config = args[:errors_config] if args.key?(:errors_config)
  @input_config = args[:input_config] if args.key?(:input_config)
  @notification_pubsub_topic = args[:notification_pubsub_topic] if args.key?(:notification_pubsub_topic)
  @reconciliation_mode = args[:reconciliation_mode] if args.key?(:reconciliation_mode)
  @request_id = args[:request_id] if args.key?(:request_id)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end