Class: Google::Apis::RetailV2::GoogleCloudRetailV2ImportProductsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb

Overview

Response of the ImportProductsRequest. If the long running operation is done, then this message is returned by the google.longrunning.Operations.response field if the operation was successful.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2ImportProductsResponse

Returns a new instance of GoogleCloudRetailV2ImportProductsResponse.



2728
2729
2730
# File 'lib/google/apis/retail_v2/classes.rb', line 2728

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_samplesArray<Google::Apis::RetailV2::GoogleRpcStatus>

A sample of errors encountered while processing the request. Corresponds to the JSON property errorSamples



2721
2722
2723
# File 'lib/google/apis/retail_v2/classes.rb', line 2721

def error_samples
  @error_samples
end

#errors_configGoogle::Apis::RetailV2::GoogleCloudRetailV2ImportErrorsConfig

Configuration of destination for Import related errors. Corresponds to the JSON property errorsConfig



2726
2727
2728
# File 'lib/google/apis/retail_v2/classes.rb', line 2726

def errors_config
  @errors_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2733
2734
2735
2736
# File 'lib/google/apis/retail_v2/classes.rb', line 2733

def update!(**args)
  @error_samples = args[:error_samples] if args.key?(:error_samples)
  @errors_config = args[:errors_config] if args.key?(:errors_config)
end