Class: Google::Apis::RetailV2::GoogleCloudRetailV2IntentClassificationConfigExample

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb

Overview

An example for intent classification.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2IntentClassificationConfigExample

Returns a new instance of GoogleCloudRetailV2IntentClassificationConfigExample.



2876
2877
2878
# File 'lib/google/apis/retail_v2/classes.rb', line 2876

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#classified_positiveBoolean Also known as: classified_positive?

Required. Whether the example is classified positively. Corresponds to the JSON property classifiedPositive

Returns:

  • (Boolean)


2855
2856
2857
# File 'lib/google/apis/retail_v2/classes.rb', line 2855

def classified_positive
  @classified_positive
end

#intent_typeString

Optional. The intent_type must match one of the predefined intent types defined at https://cloud.google.com/retail/docs/reference/rpc/google.cloud. retail.v2alpha#querytype Corresponds to the JSON property intentType

Returns:

  • (String)


2863
2864
2865
# File 'lib/google/apis/retail_v2/classes.rb', line 2863

def intent_type
  @intent_type
end

#queryString

Required. Example query. Corresponds to the JSON property query

Returns:

  • (String)


2868
2869
2870
# File 'lib/google/apis/retail_v2/classes.rb', line 2868

def query
  @query
end

#reasonString

Optional. The reason for the intent classification. This is used to explain the intent classification decision. Corresponds to the JSON property reason

Returns:

  • (String)


2874
2875
2876
# File 'lib/google/apis/retail_v2/classes.rb', line 2874

def reason
  @reason
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2881
2882
2883
2884
2885
2886
# File 'lib/google/apis/retail_v2/classes.rb', line 2881

def update!(**args)
  @classified_positive = args[:classified_positive] if args.key?(:classified_positive)
  @intent_type = args[:intent_type] if args.key?(:intent_type)
  @query = args[:query] if args.key?(:query)
  @reason = args[:reason] if args.key?(:reason)
end