Class: Google::Apis::RetailV2::GoogleCloudRetailV2ListControlsResponse
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2::GoogleCloudRetailV2ListControlsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb
Overview
Response for ListControls method.
Instance Attribute Summary collapse
-
#controls ⇒ Array<Google::Apis::RetailV2::GoogleCloudRetailV2Control>
All the Controls for a given catalog.
-
#next_page_token ⇒ String
Pagination token, if not returned indicates the last page.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2ListControlsResponse
constructor
A new instance of GoogleCloudRetailV2ListControlsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2ListControlsResponse
Returns a new instance of GoogleCloudRetailV2ListControlsResponse.
3018 3019 3020 |
# File 'lib/google/apis/retail_v2/classes.rb', line 3018 def initialize(**args) update!(**args) end |
Instance Attribute Details
#controls ⇒ Array<Google::Apis::RetailV2::GoogleCloudRetailV2Control>
All the Controls for a given catalog.
Corresponds to the JSON property controls
3011 3012 3013 |
# File 'lib/google/apis/retail_v2/classes.rb', line 3011 def controls @controls end |
#next_page_token ⇒ String
Pagination token, if not returned indicates the last page.
Corresponds to the JSON property nextPageToken
3016 3017 3018 |
# File 'lib/google/apis/retail_v2/classes.rb', line 3016 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3023 3024 3025 3026 |
# File 'lib/google/apis/retail_v2/classes.rb', line 3023 def update!(**args) @controls = args[:controls] if args.key?(:controls) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |