Class: Google::Apis::RetailV2::GoogleCloudRetailV2LocalInventory
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2::GoogleCloudRetailV2LocalInventory
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb
Overview
The inventory information at a place (e.g. a store) identified by a place ID.
Instance Attribute Summary collapse
-
#attributes ⇒ Hash<String,Google::Apis::RetailV2::GoogleCloudRetailV2CustomAttribute>
Optional.
-
#fulfillment_types ⇒ Array<String>
Optional.
-
#place_id ⇒ String
Optional.
-
#price_info ⇒ Google::Apis::RetailV2::GoogleCloudRetailV2PriceInfo
The price information of a Product.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2LocalInventory
constructor
A new instance of GoogleCloudRetailV2LocalInventory.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2LocalInventory
Returns a new instance of GoogleCloudRetailV2LocalInventory.
3164 3165 3166 |
# File 'lib/google/apis/retail_v2/classes.rb', line 3164 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attributes ⇒ Hash<String,Google::Apis::RetailV2::GoogleCloudRetailV2CustomAttribute>
Optional. Additional local inventory attributes, for example, store name,
promotion tags, etc. This field needs to pass all below criteria, otherwise an
INVALID_ARGUMENT error is returned: * At most 30 attributes are allowed. * The
key must be a UTF-8 encoded string with a length limit of 32 characters. * The
key must match the pattern: a-zA-Z0-9*. For example, key0LikeThis or
KEY_1_LIKE_THIS. * The attribute values must be of the same type (text or
number). * Only 1 value is allowed for each attribute. * For text values, the
length limit is 256 UTF-8 characters. * The attribute does not support search.
The searchable field should be unset or set to false. * The max summed total
bytes of custom attribute keys and values per product is 5MiB.
Corresponds to the JSON property attributes
3140 3141 3142 |
# File 'lib/google/apis/retail_v2/classes.rb', line 3140 def attributes @attributes end |
#fulfillment_types ⇒ Array<String>
Optional. Supported fulfillment types. Valid fulfillment type values include
commonly used types (such as pickup in store and same day delivery), and
custom types. Customers have to map custom types to their display names before
rendering UI. Supported values: * "pickup-in-store" * "ship-to-store" * "same-
day-delivery" * "next-day-delivery" * "custom-type-1" * "custom-type-2" * "
custom-type-3" * "custom-type-4" * "custom-type-5" If this field is set to an
invalid value other than these, an INVALID_ARGUMENT error is returned. All the
elements must be distinct. Otherwise, an INVALID_ARGUMENT error is returned.
Corresponds to the JSON property fulfillmentTypes
3152 3153 3154 |
# File 'lib/google/apis/retail_v2/classes.rb', line 3152 def fulfillment_types @fulfillment_types end |
#place_id ⇒ String
Optional. The place ID for the current set of inventory information.
Corresponds to the JSON property placeId
3157 3158 3159 |
# File 'lib/google/apis/retail_v2/classes.rb', line 3157 def place_id @place_id end |
#price_info ⇒ Google::Apis::RetailV2::GoogleCloudRetailV2PriceInfo
The price information of a Product.
Corresponds to the JSON property priceInfo
3162 3163 3164 |
# File 'lib/google/apis/retail_v2/classes.rb', line 3162 def price_info @price_info end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3169 3170 3171 3172 3173 3174 |
# File 'lib/google/apis/retail_v2/classes.rb', line 3169 def update!(**args) @attributes = args[:attributes] if args.key?(:attributes) @fulfillment_types = args[:fulfillment_types] if args.key?(:fulfillment_types) @place_id = args[:place_id] if args.key?(:place_id) @price_info = args[:price_info] if args.key?(:price_info) end |