Class: Google::Apis::RetailV2::GoogleCloudRetailV2Model

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb

Overview

Metadata that describes the training and serving parameters of a Model. A Model can be associated with a ServingConfig and then queried through the Predict API.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2Model

Returns a new instance of GoogleCloudRetailV2Model.



3298
3299
3300
# File 'lib/google/apis/retail_v2/classes.rb', line 3298

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp the Recommendation Model was created at. Corresponds to the JSON property createTime

Returns:

  • (String)


3186
3187
3188
# File 'lib/google/apis/retail_v2/classes.rb', line 3186

def create_time
  @create_time
end

#data_stateString

Output only. The state of data requirements for this model: DATA_OK and DATA_ERROR. Recommendation model cannot be trained if the data is in DATA_ERROR state. Recommendation model can have DATA_ERROR state even if serving state is ACTIVE: models were trained successfully before, but cannot be refreshed because model no longer has sufficient data for training. Corresponds to the JSON property dataState

Returns:

  • (String)


3195
3196
3197
# File 'lib/google/apis/retail_v2/classes.rb', line 3195

def data_state
  @data_state
end

#display_nameString

Required. The display name of the model. Should be human readable, used to display Recommendation Models in the Retail Cloud Console Dashboard. UTF-8 encoded string with limit of 1024 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


3202
3203
3204
# File 'lib/google/apis/retail_v2/classes.rb', line 3202

def display_name
  @display_name
end

#filtering_optionString

Optional. If RECOMMENDATIONS_FILTERING_ENABLED, recommendation filtering by attributes is enabled for the model. Corresponds to the JSON property filteringOption

Returns:

  • (String)


3208
3209
3210
# File 'lib/google/apis/retail_v2/classes.rb', line 3208

def filtering_option
  @filtering_option
end

#last_tune_timeString

Output only. The timestamp when the latest successful tune finished. Corresponds to the JSON property lastTuneTime

Returns:

  • (String)


3213
3214
3215
# File 'lib/google/apis/retail_v2/classes.rb', line 3213

def last_tune_time
  @last_tune_time
end

#model_features_configGoogle::Apis::RetailV2::GoogleCloudRetailV2ModelModelFeaturesConfig

Additional model features config. Corresponds to the JSON property modelFeaturesConfig



3218
3219
3220
# File 'lib/google/apis/retail_v2/classes.rb', line 3218

def model_features_config
  @model_features_config
end

#nameString

Required. The fully qualified resource name of the model. Format: projects/ project_number/locations/location_id/catalogs/catalog_id/models/model_id catalog_id has char limit of 50. recommendation_model_id has char limit of 40. Corresponds to the JSON property name

Returns:

  • (String)


3226
3227
3228
# File 'lib/google/apis/retail_v2/classes.rb', line 3226

def name
  @name
end

#optimization_objectiveString

Optional. The optimization objective e.g. cvr. Currently supported values: ctr, cvr, revenue-per-order. If not specified, we choose default based on model type. Default depends on type of recommendation: recommended-for-you => ctr others-you-may-like => ctr frequently-bought-together => revenue_per_order This field together with optimization_objective describe model metadata to use to control model training and serving. See https://cloud. google.com/retail/docs/models for more details on what the model metadata control and which combination of parameters are valid. For invalid combinations of parameters (e.g. type = frequently-bought-together and optimization_objective = ctr), you receive an error 400 if you try to create/ update a recommendation with this set of knobs. Corresponds to the JSON property optimizationObjective

Returns:

  • (String)


3241
3242
3243
# File 'lib/google/apis/retail_v2/classes.rb', line 3241

def optimization_objective
  @optimization_objective
end

#periodic_tuning_stateString

Optional. The state of periodic tuning. The period we use is 3 months - to do a one-off tune earlier use the TuneModel method. Default value is PERIODIC_TUNING_ENABLED. Corresponds to the JSON property periodicTuningState

Returns:

  • (String)


3248
3249
3250
# File 'lib/google/apis/retail_v2/classes.rb', line 3248

def periodic_tuning_state
  @periodic_tuning_state
end

#serving_config_listsArray<Google::Apis::RetailV2::GoogleCloudRetailV2ModelServingConfigList>

Output only. The list of valid serving configs associated with the PageOptimizationConfig. Corresponds to the JSON property servingConfigLists



3254
3255
3256
# File 'lib/google/apis/retail_v2/classes.rb', line 3254

def serving_config_lists
  @serving_config_lists
end

#serving_stateString

Output only. The serving state of the model: ACTIVE, NOT_ACTIVE. Corresponds to the JSON property servingState

Returns:

  • (String)


3259
3260
3261
# File 'lib/google/apis/retail_v2/classes.rb', line 3259

def serving_state
  @serving_state
end

#training_stateString

Optional. The training state that the model is in (e.g. TRAINING or PAUSED) . Since part of the cost of running the service is frequency of training - this can be used to determine when to train model in order to control cost. If not specified: the default value for CreateModel method is TRAINING. The default value for UpdateModel method is to keep the state the same as before. Corresponds to the JSON property trainingState

Returns:

  • (String)


3268
3269
3270
# File 'lib/google/apis/retail_v2/classes.rb', line 3268

def training_state
  @training_state
end

#tuning_operationString

Output only. The tune operation associated with the model. Can be used to determine if there is an ongoing tune for this recommendation. Empty field implies no tune is goig on. Corresponds to the JSON property tuningOperation

Returns:

  • (String)


3275
3276
3277
# File 'lib/google/apis/retail_v2/classes.rb', line 3275

def tuning_operation
  @tuning_operation
end

#typeString

Required. The type of model e.g. home-page. Currently supported values: recommended-for-you, others-you-may-like, frequently-bought-together, page-optimization, similar-items, buy-it-again, on-sale-items, and recently-viewed(readonly value). This field together with optimization_objective describe model metadata to use to control model training and serving. See https://cloud.google.com/retail/docs/models for more details on what the model metadata control and which combination of parameters are valid. For invalid combinations of parameters (e.g. type = frequently- bought-together and optimization_objective = ctr), you receive an error 400 if you try to create/update a recommendation with this set of knobs. Corresponds to the JSON property type

Returns:

  • (String)


3289
3290
3291
# File 'lib/google/apis/retail_v2/classes.rb', line 3289

def type
  @type
end

#update_timeString

Output only. Timestamp the Recommendation Model was last updated. E.g. if a Recommendation Model was paused - this would be the time the pause was initiated. Corresponds to the JSON property updateTime

Returns:

  • (String)


3296
3297
3298
# File 'lib/google/apis/retail_v2/classes.rb', line 3296

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3303
3304
3305
3306
3307
3308
3309
3310
3311
3312
3313
3314
3315
3316
3317
3318
3319
# File 'lib/google/apis/retail_v2/classes.rb', line 3303

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_state = args[:data_state] if args.key?(:data_state)
  @display_name = args[:display_name] if args.key?(:display_name)
  @filtering_option = args[:filtering_option] if args.key?(:filtering_option)
  @last_tune_time = args[:last_tune_time] if args.key?(:last_tune_time)
  @model_features_config = args[:model_features_config] if args.key?(:model_features_config)
  @name = args[:name] if args.key?(:name)
  @optimization_objective = args[:optimization_objective] if args.key?(:optimization_objective)
  @periodic_tuning_state = args[:periodic_tuning_state] if args.key?(:periodic_tuning_state)
  @serving_config_lists = args[:serving_config_lists] if args.key?(:serving_config_lists)
  @serving_state = args[:serving_state] if args.key?(:serving_state)
  @training_state = args[:training_state] if args.key?(:training_state)
  @tuning_operation = args[:tuning_operation] if args.key?(:tuning_operation)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
end