Class: Google::Apis::RetailV2::GoogleCloudRetailV2PanelInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb

Overview

Detailed panel information associated with a user event.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2PanelInfo

Returns a new instance of GoogleCloudRetailV2PanelInfo.



3526
3527
3528
# File 'lib/google/apis/retail_v2/classes.rb', line 3526

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attribution_tokenString

Optional. The attribution token of the panel. Corresponds to the JSON property attributionToken

Returns:

  • (String)


3497
3498
3499
# File 'lib/google/apis/retail_v2/classes.rb', line 3497

def attribution_token
  @attribution_token
end

#display_nameString

Optional. The display name of the panel. Corresponds to the JSON property displayName

Returns:

  • (String)


3502
3503
3504
# File 'lib/google/apis/retail_v2/classes.rb', line 3502

def display_name
  @display_name
end

#panel_idString

Required. The panel ID. Corresponds to the JSON property panelId

Returns:

  • (String)


3507
3508
3509
# File 'lib/google/apis/retail_v2/classes.rb', line 3507

def panel_id
  @panel_id
end

#panel_positionFixnum

Optional. The ordered position of the panel, if shown to the user with other panels. If set, then total_panels must also be set. Corresponds to the JSON property panelPosition

Returns:

  • (Fixnum)


3513
3514
3515
# File 'lib/google/apis/retail_v2/classes.rb', line 3513

def panel_position
  @panel_position
end

#product_detailsArray<Google::Apis::RetailV2::GoogleCloudRetailV2ProductDetail>

Optional. The product details associated with the panel. Corresponds to the JSON property productDetails



3518
3519
3520
# File 'lib/google/apis/retail_v2/classes.rb', line 3518

def product_details
  @product_details
end

#total_panelsFixnum

Optional. The total number of panels, including this one, shown to the user. Must be set if panel_position is set. Corresponds to the JSON property totalPanels

Returns:

  • (Fixnum)


3524
3525
3526
# File 'lib/google/apis/retail_v2/classes.rb', line 3524

def total_panels
  @total_panels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3531
3532
3533
3534
3535
3536
3537
3538
# File 'lib/google/apis/retail_v2/classes.rb', line 3531

def update!(**args)
  @attribution_token = args[:attribution_token] if args.key?(:attribution_token)
  @display_name = args[:display_name] if args.key?(:display_name)
  @panel_id = args[:panel_id] if args.key?(:panel_id)
  @panel_position = args[:panel_position] if args.key?(:panel_position)
  @product_details = args[:product_details] if args.key?(:product_details)
  @total_panels = args[:total_panels] if args.key?(:total_panels)
end