Class: Google::Apis::RetailV2::GoogleCloudRetailV2PinControlMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb

Overview

Metadata for pinning to be returned in the response. This is used for distinguishing between applied vs dropped pins.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2PinControlMetadata

Returns a new instance of GoogleCloudRetailV2PinControlMetadata.



3570
3571
3572
# File 'lib/google/apis/retail_v2/classes.rb', line 3570

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#all_matched_pinsHash<String,Google::Apis::RetailV2::GoogleCloudRetailV2PinControlMetadataProductPins>

Map of all matched pins, keyed by pin position. Corresponds to the JSON property allMatchedPins



3562
3563
3564
# File 'lib/google/apis/retail_v2/classes.rb', line 3562

def all_matched_pins
  @all_matched_pins
end

#dropped_pinsHash<String,Google::Apis::RetailV2::GoogleCloudRetailV2PinControlMetadataProductPins>

Map of pins that were dropped due to overlap with other matching pins, keyed by pin position. Corresponds to the JSON property droppedPins



3568
3569
3570
# File 'lib/google/apis/retail_v2/classes.rb', line 3568

def dropped_pins
  @dropped_pins
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3575
3576
3577
3578
# File 'lib/google/apis/retail_v2/classes.rb', line 3575

def update!(**args)
  @all_matched_pins = args[:all_matched_pins] if args.key?(:all_matched_pins)
  @dropped_pins = args[:dropped_pins] if args.key?(:dropped_pins)
end