Class: Google::Apis::RetailV2::GoogleCloudRetailV2PredictResponse
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2::GoogleCloudRetailV2PredictResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb
Overview
Response message for predict method.
Instance Attribute Summary collapse
-
#attribution_token ⇒ String
A unique attribution token.
-
#missing_ids ⇒ Array<String>
IDs of products in the request that were missing from the inventory.
-
#results ⇒ Array<Google::Apis::RetailV2::GoogleCloudRetailV2PredictResponsePredictionResult>
A list of recommended products.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
True if the validateOnly property was set in the request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2PredictResponse
constructor
A new instance of GoogleCloudRetailV2PredictResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2PredictResponse
Returns a new instance of GoogleCloudRetailV2PredictResponse.
3740 3741 3742 |
# File 'lib/google/apis/retail_v2/classes.rb', line 3740 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attribution_token ⇒ String
A unique attribution token. This should be included in the UserEvent logs
resulting from this recommendation, which enables accurate attribution of
recommendation model performance.
Corresponds to the JSON property attributionToken
3721 3722 3723 |
# File 'lib/google/apis/retail_v2/classes.rb', line 3721 def attribution_token @attribution_token end |
#missing_ids ⇒ Array<String>
IDs of products in the request that were missing from the inventory.
Corresponds to the JSON property missingIds
3726 3727 3728 |
# File 'lib/google/apis/retail_v2/classes.rb', line 3726 def missing_ids @missing_ids end |
#results ⇒ Array<Google::Apis::RetailV2::GoogleCloudRetailV2PredictResponsePredictionResult>
A list of recommended products. The order represents the ranking (from the
most relevant product to the least).
Corresponds to the JSON property results
3732 3733 3734 |
# File 'lib/google/apis/retail_v2/classes.rb', line 3732 def results @results end |
#validate_only ⇒ Boolean Also known as: validate_only?
True if the validateOnly property was set in the request.
Corresponds to the JSON property validateOnly
3737 3738 3739 |
# File 'lib/google/apis/retail_v2/classes.rb', line 3737 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3745 3746 3747 3748 3749 3750 |
# File 'lib/google/apis/retail_v2/classes.rb', line 3745 def update!(**args) @attribution_token = args[:attribution_token] if args.key?(:attribution_token) @missing_ids = args[:missing_ids] if args.key?(:missing_ids) @results = args[:results] if args.key?(:results) @validate_only = args[:validate_only] if args.key?(:validate_only) end |