Class: Google::Apis::RetailV2::GoogleCloudRetailV2ProductAttributeValue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb

Overview

Product attribute which structured by an attribute name and value. This structure is used in conversational search filters and answers. For example, if we have name=color and value=red, this means that the color is red.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2ProductAttributeValue

Returns a new instance of GoogleCloudRetailV2ProductAttributeValue.



4316
4317
4318
# File 'lib/google/apis/retail_v2/classes.rb', line 4316

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

The attribute name. Corresponds to the JSON property name

Returns:

  • (String)


4309
4310
4311
# File 'lib/google/apis/retail_v2/classes.rb', line 4309

def name
  @name
end

#valueString

The attribute value. Corresponds to the JSON property value

Returns:

  • (String)


4314
4315
4316
# File 'lib/google/apis/retail_v2/classes.rb', line 4314

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4321
4322
4323
4324
# File 'lib/google/apis/retail_v2/classes.rb', line 4321

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @value = args[:value] if args.key?(:value)
end