Class: Google::Apis::RetailV2::GoogleCloudRetailV2PurgeProductsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb

Overview

Response of the PurgeProductsRequest. If the long running operation is successfully done, then this message is returned by the google.longrunning. Operations.response field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2PurgeProductsResponse

Returns a new instance of GoogleCloudRetailV2PurgeProductsResponse.



4635
4636
4637
# File 'lib/google/apis/retail_v2/classes.rb', line 4635

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#purge_countFixnum

The total count of products purged as a result of the operation. Corresponds to the JSON property purgeCount

Returns:

  • (Fixnum)


4626
4627
4628
# File 'lib/google/apis/retail_v2/classes.rb', line 4626

def purge_count
  @purge_count
end

#purge_sampleArray<String>

A sample of the product names that will be deleted. Only populated if force is set to false. A max of 100 names will be returned and the names are chosen at random. Corresponds to the JSON property purgeSample

Returns:

  • (Array<String>)


4633
4634
4635
# File 'lib/google/apis/retail_v2/classes.rb', line 4633

def purge_sample
  @purge_sample
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4640
4641
4642
4643
# File 'lib/google/apis/retail_v2/classes.rb', line 4640

def update!(**args)
  @purge_count = args[:purge_count] if args.key?(:purge_count)
  @purge_sample = args[:purge_sample] if args.key?(:purge_sample)
end