Class: Google::Apis::RetailV2::GoogleCloudRetailV2SearchRequestBoostSpecConditionBoostSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb

Overview

Boost applies to products which match a condition.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2SearchRequestBoostSpecConditionBoostSpec

Returns a new instance of GoogleCloudRetailV2SearchRequestBoostSpecConditionBoostSpec.



5886
5887
5888
# File 'lib/google/apis/retail_v2/classes.rb', line 5886

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#boostFloat

Strength of the condition boost, which should be in [-1, 1]. Negative boost means demotion. Default is 0.0. Setting to 1.0 gives the item a big promotion. However, it does not necessarily mean that the boosted item will be the top result at all times, nor that other items will be excluded. Results could still be shown even when none of them matches the condition. And results that are significantly more relevant to the search query can still trump your heavily favored but irrelevant items. Setting to -1.0 gives the item a big demotion. However, results that are deeply relevant might still be shown. The item will have an upstream battle to get a fairly high ranking, but it is not blocked out completely. Setting to 0.0 means no boost applied. The boosting condition is ignored. Corresponds to the JSON property boost

Returns:

  • (Float)


5875
5876
5877
# File 'lib/google/apis/retail_v2/classes.rb', line 5875

def boost
  @boost
end

#conditionString

An expression which specifies a boost condition. The syntax and supported fields are the same as a filter expression. See SearchRequest.filter for detail syntax and limitations. Examples: * To boost products with product ID " product_1" or "product_2", and color "Red" or "Blue": * (id: ANY("product_1", " product_2")) AND (colorFamilies: ANY("Red","Blue")) Corresponds to the JSON property condition

Returns:

  • (String)


5884
5885
5886
# File 'lib/google/apis/retail_v2/classes.rb', line 5884

def condition
  @condition
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5891
5892
5893
5894
# File 'lib/google/apis/retail_v2/classes.rb', line 5891

def update!(**args)
  @boost = args[:boost] if args.key?(:boost)
  @condition = args[:condition] if args.key?(:condition)
end