Class: Google::Apis::RetailV2::GoogleCloudRetailV2SearchRequestTileNavigationSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb

Overview

This field specifies tile navigation related parameters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2SearchRequestTileNavigationSpec

Returns a new instance of GoogleCloudRetailV2SearchRequestTileNavigationSpec.



6293
6294
6295
# File 'lib/google/apis/retail_v2/classes.rb', line 6293

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#applied_tilesArray<Google::Apis::RetailV2::GoogleCloudRetailV2Tile>

This optional field specifies the tiles which are already clicked in client side. While the feature works without this field set, particularly for an initial query, it is highly recommended to set this field because it can improve the quality of the search response and removes possible duplicate tiles. NOTE: This field is not being used for filtering search products. Client side should also put all the applied tiles in SearchRequest.filter. Corresponds to the JSON property appliedTiles



6284
6285
6286
# File 'lib/google/apis/retail_v2/classes.rb', line 6284

def applied_tiles
  @applied_tiles
end

#tile_navigation_requestedBoolean Also known as: tile_navigation_requested?

This field specifies whether the customer would like to request tile navigation. Corresponds to the JSON property tileNavigationRequested

Returns:

  • (Boolean)


6290
6291
6292
# File 'lib/google/apis/retail_v2/classes.rb', line 6290

def tile_navigation_requested
  @tile_navigation_requested
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6298
6299
6300
6301
# File 'lib/google/apis/retail_v2/classes.rb', line 6298

def update!(**args)
  @applied_tiles = args[:applied_tiles] if args.key?(:applied_tiles)
  @tile_navigation_requested = args[:tile_navigation_requested] if args.key?(:tile_navigation_requested)
end