Class: Google::Apis::RetailV2::GoogleCloudRetailV2SearchResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb

Overview

Response message for SearchService.Search method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2SearchResponse

Returns a new instance of GoogleCloudRetailV2SearchResponse.



6395
6396
6397
# File 'lib/google/apis/retail_v2/classes.rb', line 6395

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#applied_controlsArray<String>

The fully qualified resource name of applied controls. Corresponds to the JSON property appliedControls

Returns:

  • (Array<String>)


6312
6313
6314
# File 'lib/google/apis/retail_v2/classes.rb', line 6312

def applied_controls
  @applied_controls
end

#attribution_tokenString

A unique search token. This should be included in the UserEvent logs resulting from this search, which enables accurate attribution of search model performance. Corresponds to the JSON property attributionToken

Returns:

  • (String)


6319
6320
6321
# File 'lib/google/apis/retail_v2/classes.rb', line 6319

def attribution_token
  @attribution_token
end

#conversational_search_resultGoogle::Apis::RetailV2::GoogleCloudRetailV2SearchResponseConversationalSearchResult

This field specifies all related information that is needed on client side for UI rendering of conversational retail search. Corresponds to the JSON property conversationalSearchResult



6325
6326
6327
# File 'lib/google/apis/retail_v2/classes.rb', line 6325

def conversational_search_result
  @conversational_search_result
end

#corrected_queryString

Contains the spell corrected query, if found. The search results are based on corrected_query by default. However, if SearchRequest.SpellCorrectionSpec.mode is set to SearchRequest.SpellCorrectionSpec.Mode.SUGGESTION_ONLY, the original query is used for search. Corresponds to the JSON property correctedQuery

Returns:

  • (String)


6333
6334
6335
# File 'lib/google/apis/retail_v2/classes.rb', line 6333

def corrected_query
  @corrected_query
end

#experiment_infoArray<Google::Apis::RetailV2::GoogleCloudRetailV2ExperimentInfo>

Metadata related to A/B testing experiment associated with this response. Only exists when an experiment is triggered. Corresponds to the JSON property experimentInfo



6339
6340
6341
# File 'lib/google/apis/retail_v2/classes.rb', line 6339

def experiment_info
  @experiment_info
end

#facetsArray<Google::Apis::RetailV2::GoogleCloudRetailV2SearchResponseFacet>

Results of facets requested by user. Corresponds to the JSON property facets



6344
6345
6346
# File 'lib/google/apis/retail_v2/classes.rb', line 6344

def facets
  @facets
end

#invalid_condition_boost_specsArray<Google::Apis::RetailV2::GoogleCloudRetailV2SearchRequestBoostSpecConditionBoostSpec>

The invalid SearchRequest.BoostSpec.condition_boost_specs that are not applied during serving. Corresponds to the JSON property invalidConditionBoostSpecs



6350
6351
6352
# File 'lib/google/apis/retail_v2/classes.rb', line 6350

def invalid_condition_boost_specs
  @invalid_condition_boost_specs
end

#next_page_tokenString

A token that can be sent as SearchRequest.page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


6356
6357
6358
# File 'lib/google/apis/retail_v2/classes.rb', line 6356

def next_page_token
  @next_page_token
end

#pin_control_metadataGoogle::Apis::RetailV2::GoogleCloudRetailV2PinControlMetadata

Metadata for pinning to be returned in the response. This is used for distinguishing between applied vs dropped pins. Corresponds to the JSON property pinControlMetadata



6362
6363
6364
# File 'lib/google/apis/retail_v2/classes.rb', line 6362

def 
  @pin_control_metadata
end

#query_expansion_infoGoogle::Apis::RetailV2::GoogleCloudRetailV2SearchResponseQueryExpansionInfo

Information describing query expansion including whether expansion has occurred. Corresponds to the JSON property queryExpansionInfo



6368
6369
6370
# File 'lib/google/apis/retail_v2/classes.rb', line 6368

def query_expansion_info
  @query_expansion_info
end

#redirect_uriString

The URI of a customer-defined redirect page. If redirect action is triggered, no search is performed, and only redirect_uri and attribution_token are set in the response. Corresponds to the JSON property redirectUri

Returns:

  • (String)


6375
6376
6377
# File 'lib/google/apis/retail_v2/classes.rb', line 6375

def redirect_uri
  @redirect_uri
end

#resultsArray<Google::Apis::RetailV2::GoogleCloudRetailV2SearchResponseSearchResult>

A list of matched items. The order represents the ranking. Corresponds to the JSON property results



6380
6381
6382
# File 'lib/google/apis/retail_v2/classes.rb', line 6380

def results
  @results
end

#tile_navigation_resultGoogle::Apis::RetailV2::GoogleCloudRetailV2SearchResponseTileNavigationResult

This field specifies all related information for tile navigation that will be used in client side. Corresponds to the JSON property tileNavigationResult



6386
6387
6388
# File 'lib/google/apis/retail_v2/classes.rb', line 6386

def tile_navigation_result
  @tile_navigation_result
end

#total_sizeFixnum

The estimated total count of matched items irrespective of pagination. The count of results returned by pagination may be less than the total_size that matches. Corresponds to the JSON property totalSize

Returns:

  • (Fixnum)


6393
6394
6395
# File 'lib/google/apis/retail_v2/classes.rb', line 6393

def total_size
  @total_size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6400
6401
6402
6403
6404
6405
6406
6407
6408
6409
6410
6411
6412
6413
6414
6415
# File 'lib/google/apis/retail_v2/classes.rb', line 6400

def update!(**args)
  @applied_controls = args[:applied_controls] if args.key?(:applied_controls)
  @attribution_token = args[:attribution_token] if args.key?(:attribution_token)
  @conversational_search_result = args[:conversational_search_result] if args.key?(:conversational_search_result)
  @corrected_query = args[:corrected_query] if args.key?(:corrected_query)
  @experiment_info = args[:experiment_info] if args.key?(:experiment_info)
  @facets = args[:facets] if args.key?(:facets)
  @invalid_condition_boost_specs = args[:invalid_condition_boost_specs] if args.key?(:invalid_condition_boost_specs)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @pin_control_metadata = args[:pin_control_metadata] if args.key?(:pin_control_metadata)
  @query_expansion_info = args[:query_expansion_info] if args.key?(:query_expansion_info)
  @redirect_uri = args[:redirect_uri] if args.key?(:redirect_uri)
  @results = args[:results] if args.key?(:results)
  @tile_navigation_result = args[:tile_navigation_result] if args.key?(:tile_navigation_result)
  @total_size = args[:total_size] if args.key?(:total_size)
end