Class: Google::Apis::RetailV2::GoogleCloudRetailV2SearchResponseTileNavigationResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb

Overview

This field specifies all related information for tile navigation that will be used in client side.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2SearchResponseTileNavigationResult

Returns a new instance of GoogleCloudRetailV2SearchResponseTileNavigationResult.



6709
6710
6711
# File 'lib/google/apis/retail_v2/classes.rb', line 6709

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#tilesArray<Google::Apis::RetailV2::GoogleCloudRetailV2Tile>

The current tiles that are used for tile navigation, sorted by engagement. Corresponds to the JSON property tiles



6707
6708
6709
# File 'lib/google/apis/retail_v2/classes.rb', line 6707

def tiles
  @tiles
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6714
6715
6716
# File 'lib/google/apis/retail_v2/classes.rb', line 6714

def update!(**args)
  @tiles = args[:tiles] if args.key?(:tiles)
end