Class: Google::Apis::RetailV2::GoogleCloudRetailV2UserEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb

Overview

UserEvent captures all metadata information Retail API needs to know about how end users interact with customers' website.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2UserEvent

Returns a new instance of GoogleCloudRetailV2UserEvent.



7371
7372
7373
# File 'lib/google/apis/retail_v2/classes.rb', line 7371

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attributesHash<String,Google::Apis::RetailV2::GoogleCloudRetailV2CustomAttribute>

Extra user event features to include in the recommendation model. If you provide custom attributes for ingested user events, also include them in the user events that you associate with prediction requests. Custom attribute formatting must be consistent between imported events and events provided with prediction requests. This lets the Retail API use those custom attributes when training models and serving predictions, which helps improve recommendation quality. This field needs to pass all below criteria, otherwise an INVALID_ARGUMENT error is returned: * The key must be a UTF-8 encoded string with a length limit of 5,000 characters. * For text attributes, at most 400 values are allowed. Empty values are not allowed. Each value must be a UTF-8 encoded string with a length limit of 256 characters. * For number attributes, at most 400 values are allowed. For product recommendations, an example of extra user information is traffic_channel, which is how a user arrives at the site. Users can arrive at the site by coming to the site directly, coming through Google search, or in other ways. Corresponds to the JSON property attributes



7182
7183
7184
# File 'lib/google/apis/retail_v2/classes.rb', line 7182

def attributes
  @attributes
end

#attribution_tokenString

Highly recommended for user events that are the result of PredictionService. Predict. This field enables accurate attribution of recommendation model performance. The value must be a valid PredictResponse.attribution_token for user events that are the result of PredictionService.Predict. The value must be a valid SearchResponse.attribution_token for user events that are the result of SearchService.Search. This token enables us to accurately attribute page view or purchase back to the event and the particular predict response containing this clicked/purchased product. If user clicks on product K in the recommendation results, pass PredictResponse.attribution_token as a URL parameter to product K's page. When recording events on product K's page, log the PredictResponse.attribution_token to this field. Corresponds to the JSON property attributionToken

Returns:

  • (String)


7197
7198
7199
# File 'lib/google/apis/retail_v2/classes.rb', line 7197

def attribution_token
  @attribution_token
end

#cart_idString

The ID or name of the associated shopping cart. This ID is used to associate multiple items added or present in the cart before purchase. This can only be set for add-to-cart, purchase-complete, or shopping-cart-page-view events. Corresponds to the JSON property cartId

Returns:

  • (String)


7205
7206
7207
# File 'lib/google/apis/retail_v2/classes.rb', line 7205

def cart_id
  @cart_id
end

#completion_detailGoogle::Apis::RetailV2::GoogleCloudRetailV2CompletionDetail

Detailed completion information including completion attribution token and clicked completion info. Corresponds to the JSON property completionDetail



7211
7212
7213
# File 'lib/google/apis/retail_v2/classes.rb', line 7211

def completion_detail
  @completion_detail
end

#entityString

The entity for customers that may run multiple different entities, domains, sites or regions, for example, Google US, Google Ads, Waymo, google.com , youtube.com, etc. We recommend that you set this field to get better per- entity search, completion, and prediction results. Corresponds to the JSON property entity

Returns:

  • (String)


7219
7220
7221
# File 'lib/google/apis/retail_v2/classes.rb', line 7219

def entity
  @entity
end

#event_timeString

Only required for UserEventService.ImportUserEvents method. Timestamp of when the user event happened. Corresponds to the JSON property eventTime

Returns:

  • (String)


7225
7226
7227
# File 'lib/google/apis/retail_v2/classes.rb', line 7225

def event_time
  @event_time
end

#event_typeString

Required. User event type. Allowed values are: * add-to-cart: Products being added to cart. * remove-from-cart: Products being removed from cart. * category-page-view: Special pages such as sale or promotion pages viewed. * detail-page-view: Products detail page viewed. * home-page-view: Homepage viewed. * purchase-complete: User finishing a purchase. * search: Product search. * shopping-cart-page-view: User viewing a shopping cart. Corresponds to the JSON property eventType

Returns:

  • (String)


7235
7236
7237
# File 'lib/google/apis/retail_v2/classes.rb', line 7235

def event_type
  @event_type
end

#experiment_idsArray<String>

A list of identifiers for the independent experiment groups this user event belongs to. This is used to distinguish between user events associated with different experiment setups (e.g. using Retail API, using different recommendation models). Corresponds to the JSON property experimentIds

Returns:

  • (Array<String>)


7243
7244
7245
# File 'lib/google/apis/retail_v2/classes.rb', line 7243

def experiment_ids
  @experiment_ids
end

#filterString

The filter syntax consists of an expression language for constructing a predicate from one or more fields of the products being filtered. See SearchRequest.filter for definition and syntax. The value must be a UTF-8 encoded string with a length limit of 1,000 characters. Otherwise, an INVALID_ARGUMENT error is returned. Corresponds to the JSON property filter

Returns:

  • (String)


7252
7253
7254
# File 'lib/google/apis/retail_v2/classes.rb', line 7252

def filter
  @filter
end

#offsetFixnum

An integer that specifies the current offset for pagination (the 0-indexed starting location, amongst the products deemed by the API as relevant). See SearchRequest.offset for definition. If this field is negative, an INVALID_ARGUMENT is returned. This can only be set for search events. Other event types should not set this field. Otherwise, an INVALID_ARGUMENT error is returned. Corresponds to the JSON property offset

Returns:

  • (Fixnum)


7262
7263
7264
# File 'lib/google/apis/retail_v2/classes.rb', line 7262

def offset
  @offset
end

#order_byString

The order in which products are returned. See SearchRequest.order_by for definition and syntax. The value must be a UTF-8 encoded string with a length limit of 1,000 characters. Otherwise, an INVALID_ARGUMENT error is returned. This can only be set for search events. Other event types should not set this field. Otherwise, an INVALID_ARGUMENT error is returned. Corresponds to the JSON property orderBy

Returns:

  • (String)


7271
7272
7273
# File 'lib/google/apis/retail_v2/classes.rb', line 7271

def order_by
  @order_by
end

#page_categoriesArray<String>

Optional. The categories associated with a category page. To represent the full path of category, use the '>' sign, with one space on each side, to separate different hierarchies. If '>' is part of the category name, replace it with other character(s). Category pages include special pages such as sales or promotions. For instance, a special sale page may have the category hierarchy: "pageCategories" : ["Sales > 2017 Black Friday Deals"]. Required for category-page-view events. At least one of search_query or page_categories is required for search events. Other event types should not set this field. Otherwise, an INVALID_ARGUMENT error is returned. Corresponds to the JSON property pageCategories

Returns:

  • (Array<String>)


7284
7285
7286
# File 'lib/google/apis/retail_v2/classes.rb', line 7284

def page_categories
  @page_categories
end

#page_view_idString

A unique ID of a web page view. This should be kept the same for all user events triggered from the same pageview. For example, an item detail page view could trigger multiple events as the user is browsing the page. The pageViewId property should be kept the same for all these events so that they can be grouped together properly. When using the client side event reporting with JavaScript pixel and Google Tag Manager, this value is filled in automatically. Corresponds to the JSON property pageViewId

Returns:

  • (String)


7295
7296
7297
# File 'lib/google/apis/retail_v2/classes.rb', line 7295

def page_view_id
  @page_view_id
end

#panelsArray<Google::Apis::RetailV2::GoogleCloudRetailV2PanelInfo>

Optional. List of panels associated with this event. Used for panel-level impression data. Corresponds to the JSON property panels



7301
7302
7303
# File 'lib/google/apis/retail_v2/classes.rb', line 7301

def panels
  @panels
end

#product_detailsArray<Google::Apis::RetailV2::GoogleCloudRetailV2ProductDetail>

The main product details related to the event. This field is optional except for the following event types: * add-to-cart * detail-page-view * purchase-complete In a search event, this field represents the products returned to the end user on the current page (the end user may have not finished browsing the whole page yet). When a new page is returned to the end user, after pagination/filtering/ordering even for the same query, a new search event with different product_details is desired. The end user may have not finished browsing the whole page yet. Corresponds to the JSON property productDetails



7313
7314
7315
# File 'lib/google/apis/retail_v2/classes.rb', line 7313

def product_details
  @product_details
end

#purchase_transactionGoogle::Apis::RetailV2::GoogleCloudRetailV2PurchaseTransaction

A transaction represents the entire purchase transaction. Corresponds to the JSON property purchaseTransaction



7318
7319
7320
# File 'lib/google/apis/retail_v2/classes.rb', line 7318

def purchase_transaction
  @purchase_transaction
end

#referrer_uriString

The referrer URL of the current page. When using the client side event reporting with JavaScript pixel and Google Tag Manager, this value is filled in automatically. Corresponds to the JSON property referrerUri

Returns:

  • (String)


7325
7326
7327
# File 'lib/google/apis/retail_v2/classes.rb', line 7325

def referrer_uri
  @referrer_uri
end

#search_queryString

The user's search query. See SearchRequest.query for definition. The value must be a UTF-8 encoded string with a length limit of 5,000 characters. Otherwise, an INVALID_ARGUMENT error is returned. At least one of search_query or page_categories is required for search events. Other event types should not set this field. Otherwise, an INVALID_ARGUMENT error is returned. Corresponds to the JSON property searchQuery

Returns:

  • (String)


7334
7335
7336
# File 'lib/google/apis/retail_v2/classes.rb', line 7334

def search_query
  @search_query
end

#session_idString

A unique identifier for tracking a visitor session with a length limit of 128 bytes. A session is an aggregation of an end user behavior in a time span. A general guideline to populate the session_id: 1. If user has no activity for 30 min, a new session_id should be assigned. 2. The session_id should be unique across users, suggest use uuid or add visitor_id as prefix. Corresponds to the JSON property sessionId

Returns:

  • (String)


7343
7344
7345
# File 'lib/google/apis/retail_v2/classes.rb', line 7343

def session_id
  @session_id
end

#uriString

Complete URL (window.location.href) of the user's current page. When using the client side event reporting with JavaScript pixel and Google Tag Manager, this value is filled in automatically. Maximum length 5,000 characters. Corresponds to the JSON property uri

Returns:

  • (String)


7350
7351
7352
# File 'lib/google/apis/retail_v2/classes.rb', line 7350

def uri
  @uri
end

#user_infoGoogle::Apis::RetailV2::GoogleCloudRetailV2UserInfo

Information of an end user. Corresponds to the JSON property userInfo



7355
7356
7357
# File 'lib/google/apis/retail_v2/classes.rb', line 7355

def 
  @user_info
end

#visitor_idString

Required. A unique identifier for tracking visitors. For example, this could be implemented with an HTTP cookie, which should be able to uniquely identify a visitor on a single device. This unique identifier should not change if the visitor log in/out of the website. Don't set the field to the same fixed ID for different users. This mixes the event history of those users together, which results in degraded model quality. The field must be a UTF-8 encoded string with a length limit of 128 characters. Otherwise, an INVALID_ARGUMENT error is returned. The field should not contain PII or user-data. We recommend to use Google Analytics Client ID for this field. Corresponds to the JSON property visitorId

Returns:

  • (String)


7369
7370
7371
# File 'lib/google/apis/retail_v2/classes.rb', line 7369

def visitor_id
  @visitor_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7376
7377
7378
7379
7380
7381
7382
7383
7384
7385
7386
7387
7388
7389
7390
7391
7392
7393
7394
7395
7396
7397
7398
7399
# File 'lib/google/apis/retail_v2/classes.rb', line 7376

def update!(**args)
  @attributes = args[:attributes] if args.key?(:attributes)
  @attribution_token = args[:attribution_token] if args.key?(:attribution_token)
  @cart_id = args[:cart_id] if args.key?(:cart_id)
  @completion_detail = args[:completion_detail] if args.key?(:completion_detail)
  @entity = args[:entity] if args.key?(:entity)
  @event_time = args[:event_time] if args.key?(:event_time)
  @event_type = args[:event_type] if args.key?(:event_type)
  @experiment_ids = args[:experiment_ids] if args.key?(:experiment_ids)
  @filter = args[:filter] if args.key?(:filter)
  @offset = args[:offset] if args.key?(:offset)
  @order_by = args[:order_by] if args.key?(:order_by)
  @page_categories = args[:page_categories] if args.key?(:page_categories)
  @page_view_id = args[:page_view_id] if args.key?(:page_view_id)
  @panels = args[:panels] if args.key?(:panels)
  @product_details = args[:product_details] if args.key?(:product_details)
  @purchase_transaction = args[:purchase_transaction] if args.key?(:purchase_transaction)
  @referrer_uri = args[:referrer_uri] if args.key?(:referrer_uri)
  @search_query = args[:search_query] if args.key?(:search_query)
  @session_id = args[:session_id] if args.key?(:session_id)
  @uri = args[:uri] if args.key?(:uri)
  @user_info = args[:user_info] if args.key?(:user_info)
  @visitor_id = args[:visitor_id] if args.key?(:visitor_id)
end