Class: Google::Apis::RetailV2::GoogleCloudRetailV2alphaExportAnalyticsMetricsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb

Overview

Response of the ExportAnalyticsMetricsRequest. If the long running operation was successful, then this message is returned by the google.longrunning. Operations.response field if the operation was successful.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2alphaExportAnalyticsMetricsResponse

Returns a new instance of GoogleCloudRetailV2alphaExportAnalyticsMetricsResponse.



7723
7724
7725
# File 'lib/google/apis/retail_v2/classes.rb', line 7723

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_samplesArray<Google::Apis::RetailV2::GoogleRpcStatus>

A sample of errors encountered while processing the request. Corresponds to the JSON property errorSamples



7710
7711
7712
# File 'lib/google/apis/retail_v2/classes.rb', line 7710

def error_samples
  @error_samples
end

#errors_configGoogle::Apis::RetailV2::GoogleCloudRetailV2alphaExportErrorsConfig

Configuration of destination for Export related errors. Corresponds to the JSON property errorsConfig



7715
7716
7717
# File 'lib/google/apis/retail_v2/classes.rb', line 7715

def errors_config
  @errors_config
end

#output_resultGoogle::Apis::RetailV2::GoogleCloudRetailV2alphaOutputResult

Output result that stores the information about where the exported data is stored. Corresponds to the JSON property outputResult



7721
7722
7723
# File 'lib/google/apis/retail_v2/classes.rb', line 7721

def output_result
  @output_result
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7728
7729
7730
7731
7732
# File 'lib/google/apis/retail_v2/classes.rb', line 7728

def update!(**args)
  @error_samples = args[:error_samples] if args.key?(:error_samples)
  @errors_config = args[:errors_config] if args.key?(:errors_config)
  @output_result = args[:output_result] if args.key?(:output_result)
end