Class: Google::Apis::RetailV2::GoogleCloudRetailV2alphaExportMetadata
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2::GoogleCloudRetailV2alphaExportMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb
Overview
Metadata related to the progress of the Export operation. This is returned by the google.longrunning.Operation.metadata field.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Operation create time.
-
#update_time ⇒ String
Operation last update time.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2alphaExportMetadata
constructor
A new instance of GoogleCloudRetailV2alphaExportMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2alphaExportMetadata
Returns a new instance of GoogleCloudRetailV2alphaExportMetadata.
7772 7773 7774 |
# File 'lib/google/apis/retail_v2/classes.rb', line 7772 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Operation create time.
Corresponds to the JSON property createTime
7764 7765 7766 |
# File 'lib/google/apis/retail_v2/classes.rb', line 7764 def create_time @create_time end |
#update_time ⇒ String
Operation last update time. If the operation is done, this is also the finish
time.
Corresponds to the JSON property updateTime
7770 7771 7772 |
# File 'lib/google/apis/retail_v2/classes.rb', line 7770 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7777 7778 7779 7780 |
# File 'lib/google/apis/retail_v2/classes.rb', line 7777 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @update_time = args[:update_time] if args.key?(:update_time) end |