Class: Google::Apis::RetailV2::GoogleCloudRetailV2alphaExportProductsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb

Overview

Response of the ExportProductsRequest. If the long running operation is done, then this message is returned by the google.longrunning.Operations.response field if the operation was successful.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2alphaExportProductsResponse

Returns a new instance of GoogleCloudRetailV2alphaExportProductsResponse.



7805
7806
7807
# File 'lib/google/apis/retail_v2/classes.rb', line 7805

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_samplesArray<Google::Apis::RetailV2::GoogleRpcStatus>

A sample of errors encountered while processing the request. Corresponds to the JSON property errorSamples



7792
7793
7794
# File 'lib/google/apis/retail_v2/classes.rb', line 7792

def error_samples
  @error_samples
end

#errors_configGoogle::Apis::RetailV2::GoogleCloudRetailV2alphaExportErrorsConfig

Configuration of destination for Export related errors. Corresponds to the JSON property errorsConfig



7797
7798
7799
# File 'lib/google/apis/retail_v2/classes.rb', line 7797

def errors_config
  @errors_config
end

#output_resultGoogle::Apis::RetailV2::GoogleCloudRetailV2alphaOutputResult

Output result that stores the information about where the exported data is stored. Corresponds to the JSON property outputResult



7803
7804
7805
# File 'lib/google/apis/retail_v2/classes.rb', line 7803

def output_result
  @output_result
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7810
7811
7812
7813
7814
# File 'lib/google/apis/retail_v2/classes.rb', line 7810

def update!(**args)
  @error_samples = args[:error_samples] if args.key?(:error_samples)
  @errors_config = args[:errors_config] if args.key?(:errors_config)
  @output_result = args[:output_result] if args.key?(:output_result)
end