Class: Google::Apis::RetailV2::GoogleCloudRetailV2betaImportErrorsConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb

Overview

Configuration of destination for Import related errors.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2betaImportErrorsConfig

Returns a new instance of GoogleCloudRetailV2betaImportErrorsConfig.



9115
9116
9117
# File 'lib/google/apis/retail_v2/classes.rb', line 9115

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gcs_prefixString

Google Cloud Storage prefix for import errors. This must be an empty, existing Cloud Storage directory. Import errors are written to sharded files in this directory, one per line, as a JSON-encoded google.rpc.Status message. Corresponds to the JSON property gcsPrefix

Returns:

  • (String)


9113
9114
9115
# File 'lib/google/apis/retail_v2/classes.rb', line 9113

def gcs_prefix
  @gcs_prefix
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9120
9121
9122
# File 'lib/google/apis/retail_v2/classes.rb', line 9120

def update!(**args)
  @gcs_prefix = args[:gcs_prefix] if args.key?(:gcs_prefix)
end