Class: Google::Apis::RetailV2::GoogleCloudRetailV2betaImportUserEventsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb

Overview

Response of the ImportUserEventsRequest. If the long running operation was successful, then this message is returned by the google.longrunning.Operations. response field if the operation was successful.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2betaImportUserEventsResponse

Returns a new instance of GoogleCloudRetailV2betaImportUserEventsResponse.



9230
9231
9232
# File 'lib/google/apis/retail_v2/classes.rb', line 9230

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_samplesArray<Google::Apis::RetailV2::GoogleRpcStatus>

A sample of errors encountered while processing the request. Corresponds to the JSON property errorSamples



9217
9218
9219
# File 'lib/google/apis/retail_v2/classes.rb', line 9217

def error_samples
  @error_samples
end

#errors_configGoogle::Apis::RetailV2::GoogleCloudRetailV2betaImportErrorsConfig

Configuration of destination for Import related errors. Corresponds to the JSON property errorsConfig



9222
9223
9224
# File 'lib/google/apis/retail_v2/classes.rb', line 9222

def errors_config
  @errors_config
end

#import_summaryGoogle::Apis::RetailV2::GoogleCloudRetailV2betaUserEventImportSummary

A summary of import result. The UserEventImportSummary summarizes the import status for user events. Corresponds to the JSON property importSummary



9228
9229
9230
# File 'lib/google/apis/retail_v2/classes.rb', line 9228

def import_summary
  @import_summary
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9235
9236
9237
9238
9239
# File 'lib/google/apis/retail_v2/classes.rb', line 9235

def update!(**args)
  @error_samples = args[:error_samples] if args.key?(:error_samples)
  @errors_config = args[:errors_config] if args.key?(:errors_config)
  @import_summary = args[:import_summary] if args.key?(:import_summary)
end