Class: Google::Apis::RetailV2::GoogleCloudRetailV2CollectUserEventRequest
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2::GoogleCloudRetailV2CollectUserEventRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb
Overview
Request message for CollectUserEvent method.
Instance Attribute Summary collapse
-
#ets ⇒ Fixnum
The event timestamp in milliseconds.
-
#prebuilt_rule ⇒ String
The prebuilt rule name that can convert a specific type of raw_json.
-
#raw_json ⇒ String
An arbitrary serialized JSON string that contains necessary information that can comprise a user event.
-
#uri ⇒ String
The URL including cgi-parameters but excluding the hash fragment with a length limit of 5,000 characters.
-
#user_event ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2CollectUserEventRequest
constructor
A new instance of GoogleCloudRetailV2CollectUserEventRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2CollectUserEventRequest
Returns a new instance of GoogleCloudRetailV2CollectUserEventRequest.
1074 1075 1076 |
# File 'lib/google/apis/retail_v2/classes.rb', line 1074 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ets ⇒ Fixnum
The event timestamp in milliseconds. This prevents browser caching of
otherwise identical get requests. The name is abbreviated to reduce the
payload bytes.
Corresponds to the JSON property ets
1045 1046 1047 |
# File 'lib/google/apis/retail_v2/classes.rb', line 1045 def ets @ets end |
#prebuilt_rule ⇒ String
The prebuilt rule name that can convert a specific type of raw_json. For
example: "ga4_bq" rule for the GA4 user event schema.
Corresponds to the JSON property prebuiltRule
1051 1052 1053 |
# File 'lib/google/apis/retail_v2/classes.rb', line 1051 def prebuilt_rule @prebuilt_rule end |
#raw_json ⇒ String
An arbitrary serialized JSON string that contains necessary information that
can comprise a user event. When this field is specified, the user_event field
will be ignored. Note: line-delimited JSON is not supported, a single JSON
only.
Corresponds to the JSON property rawJson
1059 1060 1061 |
# File 'lib/google/apis/retail_v2/classes.rb', line 1059 def raw_json @raw_json end |
#uri ⇒ String
The URL including cgi-parameters but excluding the hash fragment with a length
limit of 5,000 characters. This is often more useful than the referer URL,
because many browsers only send the domain for 3rd party requests.
Corresponds to the JSON property uri
1066 1067 1068 |
# File 'lib/google/apis/retail_v2/classes.rb', line 1066 def uri @uri end |
#user_event ⇒ String
Required. URL encoded UserEvent proto with a length limit of 2,000,000
characters.
Corresponds to the JSON property userEvent
1072 1073 1074 |
# File 'lib/google/apis/retail_v2/classes.rb', line 1072 def user_event @user_event end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1079 1080 1081 1082 1083 1084 1085 |
# File 'lib/google/apis/retail_v2/classes.rb', line 1079 def update!(**args) @ets = args[:ets] if args.key?(:ets) @prebuilt_rule = args[:prebuilt_rule] if args.key?(:prebuilt_rule) @raw_json = args[:raw_json] if args.key?(:raw_json) @uri = args[:uri] if args.key?(:uri) @user_event = args[:user_event] if args.key?(:user_event) end |