Class: Google::Apis::RetailV2::GoogleCloudRetailV2ConversationalSearchResponse
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2::GoogleCloudRetailV2ConversationalSearchResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb
Overview
Response message for ConversationalSearchService.ConversationalSearch method.
Instance Attribute Summary collapse
-
#conversation_id ⇒ String
Conversation UUID.
-
#conversational_filtering_result ⇒ Google::Apis::RetailV2::GoogleCloudRetailV2ConversationalSearchResponseConversationalFilteringResult
This field specifies all related information that is needed on client side for UI rendering of conversational filtering search.
-
#conversational_text_response ⇒ String
The conversational answer-based text response generated by the Server.
-
#followup_question ⇒ Google::Apis::RetailV2::GoogleCloudRetailV2ConversationalSearchResponseFollowupQuestion
The conversational followup question generated for Intent refinement.
-
#refined_search ⇒ Array<Google::Apis::RetailV2::GoogleCloudRetailV2ConversationalSearchResponseRefinedSearch>
The proposed refined search queries.
-
#state ⇒ String
Output only.
-
#user_query_types ⇒ Array<String>
The types Retail classifies the search query as.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2ConversationalSearchResponse
constructor
A new instance of GoogleCloudRetailV2ConversationalSearchResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2ConversationalSearchResponse
Returns a new instance of GoogleCloudRetailV2ConversationalSearchResponse.
1867 1868 1869 |
# File 'lib/google/apis/retail_v2/classes.rb', line 1867 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversation_id ⇒ String
Conversation UUID. This field will be stored in client side storage to
maintain the conversation session with server and will be used for next search
request's ConversationalSearchRequest.conversation_id to restore conversation
state in server.
Corresponds to the JSON property conversationId
1828 1829 1830 |
# File 'lib/google/apis/retail_v2/classes.rb', line 1828 def conversation_id @conversation_id end |
#conversational_filtering_result ⇒ Google::Apis::RetailV2::GoogleCloudRetailV2ConversationalSearchResponseConversationalFilteringResult
This field specifies all related information that is needed on client side for
UI rendering of conversational filtering search.
Corresponds to the JSON property conversationalFilteringResult
1834 1835 1836 |
# File 'lib/google/apis/retail_v2/classes.rb', line 1834 def conversational_filtering_result @conversational_filtering_result end |
#conversational_text_response ⇒ String
The conversational answer-based text response generated by the Server.
Corresponds to the JSON property conversationalTextResponse
1839 1840 1841 |
# File 'lib/google/apis/retail_v2/classes.rb', line 1839 def conversational_text_response @conversational_text_response end |
#followup_question ⇒ Google::Apis::RetailV2::GoogleCloudRetailV2ConversationalSearchResponseFollowupQuestion
The conversational followup question generated for Intent refinement.
Corresponds to the JSON property followupQuestion
1844 1845 1846 |
# File 'lib/google/apis/retail_v2/classes.rb', line 1844 def followup_question @followup_question end |
#refined_search ⇒ Array<Google::Apis::RetailV2::GoogleCloudRetailV2ConversationalSearchResponseRefinedSearch>
The proposed refined search queries. They can be used to fetch the relevant
search results. When using CONVERSATIONAL_FILTER_ONLY mode, the refined_query
from search response will be populated here.
Corresponds to the JSON property refinedSearch
1851 1852 1853 |
# File 'lib/google/apis/retail_v2/classes.rb', line 1851 def refined_search @refined_search end |
#state ⇒ String
Output only. The state of the response generation.
Corresponds to the JSON property state
1856 1857 1858 |
# File 'lib/google/apis/retail_v2/classes.rb', line 1856 def state @state end |
#user_query_types ⇒ Array<String>
The types Retail classifies the search query as. Supported values are: - "
ORDER_SUPPORT" - "SIMPLE_PRODUCT_SEARCH" - "INTENT_REFINEMENT" - "
PRODUCT_DETAILS" - "PRODUCT_COMPARISON" - "DEALS_AND_COUPONS" - "
STORE_RELEVANT" - "BLOCKLISTED" - "BEST_PRODUCT" - "RETAIL_SUPPORT" - "
DISABLED"
Corresponds to the JSON property userQueryTypes
1865 1866 1867 |
# File 'lib/google/apis/retail_v2/classes.rb', line 1865 def user_query_types @user_query_types end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1872 1873 1874 1875 1876 1877 1878 1879 1880 |
# File 'lib/google/apis/retail_v2/classes.rb', line 1872 def update!(**args) @conversation_id = args[:conversation_id] if args.key?(:conversation_id) @conversational_filtering_result = args[:conversational_filtering_result] if args.key?(:conversational_filtering_result) @conversational_text_response = args[:conversational_text_response] if args.key?(:conversational_text_response) @followup_question = args[:followup_question] if args.key?(:followup_question) @refined_search = args[:refined_search] if args.key?(:refined_search) @state = args[:state] if args.key?(:state) @user_query_types = args[:user_query_types] if args.key?(:user_query_types) end |