Class: Google::Apis::RetailV2::GoogleCloudRetailV2ExportAnalyticsMetricsResponse
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2::GoogleCloudRetailV2ExportAnalyticsMetricsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb
Overview
Response of the ExportAnalyticsMetricsRequest. If the long running operation was successful, then this message is returned by the google.longrunning. Operations.response field if the operation was successful.
Instance Attribute Summary collapse
-
#error_samples ⇒ Array<Google::Apis::RetailV2::GoogleRpcStatus>
A sample of errors encountered while processing the request.
-
#errors_config ⇒ Google::Apis::RetailV2::GoogleCloudRetailV2ExportErrorsConfig
Configuration of destination for Export related errors.
-
#output_result ⇒ Google::Apis::RetailV2::GoogleCloudRetailV2OutputResult
Output result that stores the information about where the exported data is stored.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2ExportAnalyticsMetricsResponse
constructor
A new instance of GoogleCloudRetailV2ExportAnalyticsMetricsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2ExportAnalyticsMetricsResponse
Returns a new instance of GoogleCloudRetailV2ExportAnalyticsMetricsResponse.
2207 2208 2209 |
# File 'lib/google/apis/retail_v2/classes.rb', line 2207 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_samples ⇒ Array<Google::Apis::RetailV2::GoogleRpcStatus>
A sample of errors encountered while processing the request.
Corresponds to the JSON property errorSamples
2194 2195 2196 |
# File 'lib/google/apis/retail_v2/classes.rb', line 2194 def error_samples @error_samples end |
#errors_config ⇒ Google::Apis::RetailV2::GoogleCloudRetailV2ExportErrorsConfig
Configuration of destination for Export related errors.
Corresponds to the JSON property errorsConfig
2199 2200 2201 |
# File 'lib/google/apis/retail_v2/classes.rb', line 2199 def errors_config @errors_config end |
#output_result ⇒ Google::Apis::RetailV2::GoogleCloudRetailV2OutputResult
Output result that stores the information about where the exported data is
stored.
Corresponds to the JSON property outputResult
2205 2206 2207 |
# File 'lib/google/apis/retail_v2/classes.rb', line 2205 def output_result @output_result end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2212 2213 2214 2215 2216 |
# File 'lib/google/apis/retail_v2/classes.rb', line 2212 def update!(**args) @error_samples = args[:error_samples] if args.key?(:error_samples) @errors_config = args[:errors_config] if args.key?(:errors_config) @output_result = args[:output_result] if args.key?(:output_result) end |