Class: Google::Apis::RetailV2::GoogleCloudRetailV2Image
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2::GoogleCloudRetailV2Image
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb
Overview
Product image. Recommendations AI and Retail Search use product images to improve prediction and search results. Product images can be returned in results, and are shown in prediction or search previews in the console. Please try to provide correct product images and avoid using images with size too small.
Instance Attribute Summary collapse
-
#height ⇒ Fixnum
Height of the image in number of pixels.
-
#uri ⇒ String
Required.
-
#width ⇒ Fixnum
Width of the image in number of pixels.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2Image
constructor
A new instance of GoogleCloudRetailV2Image.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2Image
Returns a new instance of GoogleCloudRetailV2Image.
2516 2517 2518 |
# File 'lib/google/apis/retail_v2/classes.rb', line 2516 def initialize(**args) update!(**args) end |
Instance Attribute Details
#height ⇒ Fixnum
Height of the image in number of pixels. This field must be nonnegative.
Otherwise, an INVALID_ARGUMENT error is returned.
Corresponds to the JSON property height
2499 2500 2501 |
# File 'lib/google/apis/retail_v2/classes.rb', line 2499 def height @height end |
#uri ⇒ String
Required. URI of the image. This field must be a valid UTF-8 encoded URI with
a length limit of 5,000 characters. Otherwise, an INVALID_ARGUMENT error is
returned. Google Merchant Center property image_link. Schema.org property Product.image.
Corresponds to the JSON property uri
2508 2509 2510 |
# File 'lib/google/apis/retail_v2/classes.rb', line 2508 def uri @uri end |
#width ⇒ Fixnum
Width of the image in number of pixels. This field must be nonnegative.
Otherwise, an INVALID_ARGUMENT error is returned.
Corresponds to the JSON property width
2514 2515 2516 |
# File 'lib/google/apis/retail_v2/classes.rb', line 2514 def width @width end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2521 2522 2523 2524 2525 |
# File 'lib/google/apis/retail_v2/classes.rb', line 2521 def update!(**args) @height = args[:height] if args.key?(:height) @uri = args[:uri] if args.key?(:uri) @width = args[:width] if args.key?(:width) end |