Class: Google::Apis::RetailV2::GoogleCloudRetailV2PurchaseTransaction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb

Overview

A transaction represents the entire purchase transaction.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2PurchaseTransaction

Returns a new instance of GoogleCloudRetailV2PurchaseTransaction.



4508
4509
4510
# File 'lib/google/apis/retail_v2/classes.rb', line 4508

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#costFloat

All the costs associated with the products. These can be manufacturing costs, shipping expenses not borne by the end user, or any other costs, such that: * Profit = revenue - tax - cost Corresponds to the JSON property cost

Returns:

  • (Float)


4484
4485
4486
# File 'lib/google/apis/retail_v2/classes.rb', line 4484

def cost
  @cost
end

#currency_codeString

Required. Currency code. Use three-character ISO-4217 code. Corresponds to the JSON property currencyCode

Returns:

  • (String)


4489
4490
4491
# File 'lib/google/apis/retail_v2/classes.rb', line 4489

def currency_code
  @currency_code
end

#idString

The transaction ID with a length limit of 128 characters. Corresponds to the JSON property id

Returns:

  • (String)


4494
4495
4496
# File 'lib/google/apis/retail_v2/classes.rb', line 4494

def id
  @id
end

#revenueFloat

Required. Total non-zero revenue or grand total associated with the transaction. This value include shipping, tax, or other adjustments to total revenue that you want to include as part of your revenue calculations. Corresponds to the JSON property revenue

Returns:

  • (Float)


4501
4502
4503
# File 'lib/google/apis/retail_v2/classes.rb', line 4501

def revenue
  @revenue
end

#taxFloat

All the taxes associated with the transaction. Corresponds to the JSON property tax

Returns:

  • (Float)


4506
4507
4508
# File 'lib/google/apis/retail_v2/classes.rb', line 4506

def tax
  @tax
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4513
4514
4515
4516
4517
4518
4519
# File 'lib/google/apis/retail_v2/classes.rb', line 4513

def update!(**args)
  @cost = args[:cost] if args.key?(:cost)
  @currency_code = args[:currency_code] if args.key?(:currency_code)
  @id = args[:id] if args.key?(:id)
  @revenue = args[:revenue] if args.key?(:revenue)
  @tax = args[:tax] if args.key?(:tax)
end