Class: Google::Apis::RetailV2::GoogleCloudRetailV2SafetySetting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb

Overview

Safety settings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2SafetySetting

Returns a new instance of GoogleCloudRetailV2SafetySetting.



5544
5545
5546
# File 'lib/google/apis/retail_v2/classes.rb', line 5544

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categoryString

Harm category. Corresponds to the JSON property category

Returns:

  • (String)


5531
5532
5533
# File 'lib/google/apis/retail_v2/classes.rb', line 5531

def category
  @category
end

#method_propString

Optional. Specify if the threshold is used for probability or severity score. If not specified, the threshold is used for probability score. Corresponds to the JSON property method

Returns:

  • (String)


5537
5538
5539
# File 'lib/google/apis/retail_v2/classes.rb', line 5537

def method_prop
  @method_prop
end

#thresholdString

The harm block threshold. Corresponds to the JSON property threshold

Returns:

  • (String)


5542
5543
5544
# File 'lib/google/apis/retail_v2/classes.rb', line 5542

def threshold
  @threshold
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5549
5550
5551
5552
5553
# File 'lib/google/apis/retail_v2/classes.rb', line 5549

def update!(**args)
  @category = args[:category] if args.key?(:category)
  @method_prop = args[:method_prop] if args.key?(:method_prop)
  @threshold = args[:threshold] if args.key?(:threshold)
end