Class: Google::Apis::RetailV2::GoogleCloudRetailV2SearchRequestConversationalSearchSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb

Overview

This field specifies all conversational related parameters addition to traditional retail search.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2SearchRequestConversationalSearchSpec

Returns a new instance of GoogleCloudRetailV2SearchRequestConversationalSearchSpec.



5926
5927
5928
# File 'lib/google/apis/retail_v2/classes.rb', line 5926

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversation_idString

This field specifies the conversation id, which maintains the state of the conversation between client side and server side. Use the value from the previous SearchResponse.ConversationalSearchResult.conversation_id. For the initial request, this should be empty. Corresponds to the JSON property conversationId

Returns:

  • (String)


5908
5909
5910
# File 'lib/google/apis/retail_v2/classes.rb', line 5908

def conversation_id
  @conversation_id
end

#followup_conversation_requestedBoolean Also known as: followup_conversation_requested?

This field specifies whether the customer would like to do conversational search. If this field is set to true, conversational related extra information will be returned from server side, including follow-up question, answer options, etc. Corresponds to the JSON property followupConversationRequested

Returns:

  • (Boolean)


5916
5917
5918
# File 'lib/google/apis/retail_v2/classes.rb', line 5916

def followup_conversation_requested
  @followup_conversation_requested
end

#user_answerGoogle::Apis::RetailV2::GoogleCloudRetailV2SearchRequestConversationalSearchSpecUserAnswer

This field specifies the current user answer during the conversational search. This can be either user selected from suggested answers or user input plain text. Corresponds to the JSON property userAnswer



5924
5925
5926
# File 'lib/google/apis/retail_v2/classes.rb', line 5924

def user_answer
  @user_answer
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5931
5932
5933
5934
5935
# File 'lib/google/apis/retail_v2/classes.rb', line 5931

def update!(**args)
  @conversation_id = args[:conversation_id] if args.key?(:conversation_id)
  @followup_conversation_requested = args[:followup_conversation_requested] if args.key?(:followup_conversation_requested)
  @user_answer = args[:user_answer] if args.key?(:user_answer)
end