Class: Google::Apis::RetailV2::GoogleCloudRetailV2SearchRequestConversationalSearchSpecUserAnswer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb

Overview

This field specifies the current user answer during the conversational search. This can be either user selected from suggested answers or user input plain text.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2SearchRequestConversationalSearchSpecUserAnswer

Returns a new instance of GoogleCloudRetailV2SearchRequestConversationalSearchSpecUserAnswer.



5955
5956
5957
# File 'lib/google/apis/retail_v2/classes.rb', line 5955

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#selected_answerGoogle::Apis::RetailV2::GoogleCloudRetailV2SearchRequestConversationalSearchSpecUserAnswerSelectedAnswer

This field specifies the selected answers during the conversational search. Corresponds to the JSON property selectedAnswer



5947
5948
5949
# File 'lib/google/apis/retail_v2/classes.rb', line 5947

def selected_answer
  @selected_answer
end

#text_answerString

This field specifies the incremental input text from the user during the conversational search. Corresponds to the JSON property textAnswer

Returns:

  • (String)


5953
5954
5955
# File 'lib/google/apis/retail_v2/classes.rb', line 5953

def text_answer
  @text_answer
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5960
5961
5962
5963
# File 'lib/google/apis/retail_v2/classes.rb', line 5960

def update!(**args)
  @selected_answer = args[:selected_answer] if args.key?(:selected_answer)
  @text_answer = args[:text_answer] if args.key?(:text_answer)
end