Class: Google::Apis::RetailV2::GoogleCloudRetailV2SearchRequestQueryExpansionSpec
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2::GoogleCloudRetailV2SearchRequestQueryExpansionSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb
Overview
Specification to determine under which conditions query expansion should occur.
Instance Attribute Summary collapse
-
#condition ⇒ String
The condition under which query expansion should occur.
-
#pin_unexpanded_results ⇒ Boolean
(also: #pin_unexpanded_results?)
Whether to pin unexpanded results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2SearchRequestQueryExpansionSpec
constructor
A new instance of GoogleCloudRetailV2SearchRequestQueryExpansionSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2SearchRequestQueryExpansionSpec
Returns a new instance of GoogleCloudRetailV2SearchRequestQueryExpansionSpec.
6240 6241 6242 |
# File 'lib/google/apis/retail_v2/classes.rb', line 6240 def initialize(**args) update!(**args) end |
Instance Attribute Details
#condition ⇒ String
The condition under which query expansion should occur. Default to Condition.
DISABLED.
Corresponds to the JSON property condition
6230 6231 6232 |
# File 'lib/google/apis/retail_v2/classes.rb', line 6230 def condition @condition end |
#pin_unexpanded_results ⇒ Boolean Also known as: pin_unexpanded_results?
Whether to pin unexpanded results. The default value is false. If this field
is set to true, unexpanded products are always at the top of the search
results, followed by the expanded results.
Corresponds to the JSON property pinUnexpandedResults
6237 6238 6239 |
# File 'lib/google/apis/retail_v2/classes.rb', line 6237 def @pin_unexpanded_results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6245 6246 6247 6248 |
# File 'lib/google/apis/retail_v2/classes.rb', line 6245 def update!(**args) @condition = args[:condition] if args.key?(:condition) @pin_unexpanded_results = args[:pin_unexpanded_results] if args.key?(:pin_unexpanded_results) end |