Class: Google::Apis::RetailV2::GoogleCloudRetailV2SearchResponse
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2::GoogleCloudRetailV2SearchResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb
Overview
Response message for SearchService.Search method.
Instance Attribute Summary collapse
-
#applied_controls ⇒ Array<String>
The fully qualified resource name of applied controls.
-
#attribution_token ⇒ String
A unique search token.
-
#conversational_search_result ⇒ Google::Apis::RetailV2::GoogleCloudRetailV2SearchResponseConversationalSearchResult
This field specifies all related information that is needed on client side for UI rendering of conversational retail search.
-
#corrected_query ⇒ String
Contains the spell corrected query, if found.
-
#experiment_info ⇒ Array<Google::Apis::RetailV2::GoogleCloudRetailV2ExperimentInfo>
Metadata related to A/B testing experiment associated with this response.
-
#facets ⇒ Array<Google::Apis::RetailV2::GoogleCloudRetailV2SearchResponseFacet>
Results of facets requested by user.
-
#invalid_condition_boost_specs ⇒ Array<Google::Apis::RetailV2::GoogleCloudRetailV2SearchRequestBoostSpecConditionBoostSpec>
The invalid SearchRequest.BoostSpec.condition_boost_specs that are not applied during serving.
-
#next_page_token ⇒ String
A token that can be sent as SearchRequest.page_token to retrieve the next page.
-
#pin_control_metadata ⇒ Google::Apis::RetailV2::GoogleCloudRetailV2PinControlMetadata
Metadata for pinning to be returned in the response.
-
#query_expansion_info ⇒ Google::Apis::RetailV2::GoogleCloudRetailV2SearchResponseQueryExpansionInfo
Information describing query expansion including whether expansion has occurred.
-
#redirect_uri ⇒ String
The URI of a customer-defined redirect page.
-
#results ⇒ Array<Google::Apis::RetailV2::GoogleCloudRetailV2SearchResponseSearchResult>
A list of matched items.
-
#tile_navigation_result ⇒ Google::Apis::RetailV2::GoogleCloudRetailV2SearchResponseTileNavigationResult
This field specifies all related information for tile navigation that will be used in client side.
-
#total_size ⇒ Fixnum
The estimated total count of matched items irrespective of pagination.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2SearchResponse
constructor
A new instance of GoogleCloudRetailV2SearchResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2SearchResponse
Returns a new instance of GoogleCloudRetailV2SearchResponse.
6393 6394 6395 |
# File 'lib/google/apis/retail_v2/classes.rb', line 6393 def initialize(**args) update!(**args) end |
Instance Attribute Details
#applied_controls ⇒ Array<String>
The fully qualified resource name of applied controls.
Corresponds to the JSON property appliedControls
6311 6312 6313 |
# File 'lib/google/apis/retail_v2/classes.rb', line 6311 def applied_controls @applied_controls end |
#attribution_token ⇒ String
A unique search token. This should be included in the UserEvent logs resulting
from this search, which enables accurate attribution of search model
performance.
Corresponds to the JSON property attributionToken
6318 6319 6320 |
# File 'lib/google/apis/retail_v2/classes.rb', line 6318 def attribution_token @attribution_token end |
#conversational_search_result ⇒ Google::Apis::RetailV2::GoogleCloudRetailV2SearchResponseConversationalSearchResult
This field specifies all related information that is needed on client side for
UI rendering of conversational retail search.
Corresponds to the JSON property conversationalSearchResult
6324 6325 6326 |
# File 'lib/google/apis/retail_v2/classes.rb', line 6324 def conversational_search_result @conversational_search_result end |
#corrected_query ⇒ String
Contains the spell corrected query, if found. If the spell correction type is
AUTOMATIC, then the search results are based on corrected_query. Otherwise the
original query is used for search.
Corresponds to the JSON property correctedQuery
6331 6332 6333 |
# File 'lib/google/apis/retail_v2/classes.rb', line 6331 def corrected_query @corrected_query end |
#experiment_info ⇒ Array<Google::Apis::RetailV2::GoogleCloudRetailV2ExperimentInfo>
Metadata related to A/B testing experiment associated with this response. Only
exists when an experiment is triggered.
Corresponds to the JSON property experimentInfo
6337 6338 6339 |
# File 'lib/google/apis/retail_v2/classes.rb', line 6337 def experiment_info @experiment_info end |
#facets ⇒ Array<Google::Apis::RetailV2::GoogleCloudRetailV2SearchResponseFacet>
Results of facets requested by user.
Corresponds to the JSON property facets
6342 6343 6344 |
# File 'lib/google/apis/retail_v2/classes.rb', line 6342 def facets @facets end |
#invalid_condition_boost_specs ⇒ Array<Google::Apis::RetailV2::GoogleCloudRetailV2SearchRequestBoostSpecConditionBoostSpec>
The invalid SearchRequest.BoostSpec.condition_boost_specs that are not applied
during serving.
Corresponds to the JSON property invalidConditionBoostSpecs
6348 6349 6350 |
# File 'lib/google/apis/retail_v2/classes.rb', line 6348 def invalid_condition_boost_specs @invalid_condition_boost_specs end |
#next_page_token ⇒ String
A token that can be sent as SearchRequest.page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
Corresponds to the JSON property nextPageToken
6354 6355 6356 |
# File 'lib/google/apis/retail_v2/classes.rb', line 6354 def next_page_token @next_page_token end |
#pin_control_metadata ⇒ Google::Apis::RetailV2::GoogleCloudRetailV2PinControlMetadata
Metadata for pinning to be returned in the response. This is used for
distinguishing between applied vs dropped pins.
Corresponds to the JSON property pinControlMetadata
6360 6361 6362 |
# File 'lib/google/apis/retail_v2/classes.rb', line 6360 def @pin_control_metadata end |
#query_expansion_info ⇒ Google::Apis::RetailV2::GoogleCloudRetailV2SearchResponseQueryExpansionInfo
Information describing query expansion including whether expansion has
occurred.
Corresponds to the JSON property queryExpansionInfo
6366 6367 6368 |
# File 'lib/google/apis/retail_v2/classes.rb', line 6366 def query_expansion_info @query_expansion_info end |
#redirect_uri ⇒ String
The URI of a customer-defined redirect page. If redirect action is triggered,
no search is performed, and only redirect_uri and attribution_token are set in
the response.
Corresponds to the JSON property redirectUri
6373 6374 6375 |
# File 'lib/google/apis/retail_v2/classes.rb', line 6373 def redirect_uri @redirect_uri end |
#results ⇒ Array<Google::Apis::RetailV2::GoogleCloudRetailV2SearchResponseSearchResult>
A list of matched items. The order represents the ranking.
Corresponds to the JSON property results
6378 6379 6380 |
# File 'lib/google/apis/retail_v2/classes.rb', line 6378 def results @results end |
#tile_navigation_result ⇒ Google::Apis::RetailV2::GoogleCloudRetailV2SearchResponseTileNavigationResult
This field specifies all related information for tile navigation that will be
used in client side.
Corresponds to the JSON property tileNavigationResult
6384 6385 6386 |
# File 'lib/google/apis/retail_v2/classes.rb', line 6384 def @tile_navigation_result end |
#total_size ⇒ Fixnum
The estimated total count of matched items irrespective of pagination. The
count of results returned by pagination may be less than the total_size that
matches.
Corresponds to the JSON property totalSize
6391 6392 6393 |
# File 'lib/google/apis/retail_v2/classes.rb', line 6391 def total_size @total_size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 6411 6412 6413 |
# File 'lib/google/apis/retail_v2/classes.rb', line 6398 def update!(**args) @applied_controls = args[:applied_controls] if args.key?(:applied_controls) @attribution_token = args[:attribution_token] if args.key?(:attribution_token) @conversational_search_result = args[:conversational_search_result] if args.key?(:conversational_search_result) @corrected_query = args[:corrected_query] if args.key?(:corrected_query) @experiment_info = args[:experiment_info] if args.key?(:experiment_info) @facets = args[:facets] if args.key?(:facets) @invalid_condition_boost_specs = args[:invalid_condition_boost_specs] if args.key?(:invalid_condition_boost_specs) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @pin_control_metadata = args[:pin_control_metadata] if args.key?(:pin_control_metadata) @query_expansion_info = args[:query_expansion_info] if args.key?(:query_expansion_info) @redirect_uri = args[:redirect_uri] if args.key?(:redirect_uri) @results = args[:results] if args.key?(:results) @tile_navigation_result = args[:tile_navigation_result] if args.key?(:tile_navigation_result) @total_size = args[:total_size] if args.key?(:total_size) end |