Class: Google::Apis::RetailV2::GoogleCloudRetailV2SearchResponseConversationalSearchResult
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2::GoogleCloudRetailV2SearchResponseConversationalSearchResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb
Overview
This field specifies all related information that is needed on client side for UI rendering of conversational retail search.
Instance Attribute Summary collapse
-
#additional_filter ⇒ Google::Apis::RetailV2::GoogleCloudRetailV2SearchResponseConversationalSearchResultAdditionalFilter
Additional filter that client side need to apply.
-
#additional_filters ⇒ Array<Google::Apis::RetailV2::GoogleCloudRetailV2SearchResponseConversationalSearchResultAdditionalFilter>
This field is deprecated but will be kept for backward compatibility.
-
#conversation_id ⇒ String
Conversation UUID.
-
#followup_question ⇒ String
The follow-up question.
-
#refined_query ⇒ String
The current refined query for the conversational search.
-
#suggested_answers ⇒ Array<Google::Apis::RetailV2::GoogleCloudRetailV2SearchResponseConversationalSearchResultSuggestedAnswer>
The answer options provided to client for the follow-up question.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2SearchResponseConversationalSearchResult
constructor
A new instance of GoogleCloudRetailV2SearchResponseConversationalSearchResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2SearchResponseConversationalSearchResult
Returns a new instance of GoogleCloudRetailV2SearchResponseConversationalSearchResult.
6461 6462 6463 |
# File 'lib/google/apis/retail_v2/classes.rb', line 6461 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_filter ⇒ Google::Apis::RetailV2::GoogleCloudRetailV2SearchResponseConversationalSearchResultAdditionalFilter
Additional filter that client side need to apply.
Corresponds to the JSON property additionalFilter
6424 6425 6426 |
# File 'lib/google/apis/retail_v2/classes.rb', line 6424 def additional_filter @additional_filter end |
#additional_filters ⇒ Array<Google::Apis::RetailV2::GoogleCloudRetailV2SearchResponseConversationalSearchResultAdditionalFilter>
This field is deprecated but will be kept for backward compatibility. There is
expected to have only one additional filter and the value will be the same to
the same as field additional_filter.
Corresponds to the JSON property additionalFilters
6431 6432 6433 |
# File 'lib/google/apis/retail_v2/classes.rb', line 6431 def additional_filters @additional_filters end |
#conversation_id ⇒ String
Conversation UUID. This field will be stored in client side storage to
maintain the conversation session with server and will be used for next search
request's SearchRequest.ConversationalSearchSpec.conversation_id to restore
conversation state in server.
Corresponds to the JSON property conversationId
6439 6440 6441 |
# File 'lib/google/apis/retail_v2/classes.rb', line 6439 def conversation_id @conversation_id end |
#followup_question ⇒ String
The follow-up question. e.g., What is the color?
Corresponds to the JSON property followupQuestion
6444 6445 6446 |
# File 'lib/google/apis/retail_v2/classes.rb', line 6444 def followup_question @followup_question end |
#refined_query ⇒ String
The current refined query for the conversational search. This field will be
used in customer UI that the query in the search bar should be replaced with
the refined query. For example, if SearchRequest.query is dress and next
SearchRequest.ConversationalSearchSpec.UserAnswer.text_answer is red color,
which does not match any product attribute value filters, the refined query
will be dress, red color.
Corresponds to the JSON property refinedQuery
6454 6455 6456 |
# File 'lib/google/apis/retail_v2/classes.rb', line 6454 def refined_query @refined_query end |
#suggested_answers ⇒ Array<Google::Apis::RetailV2::GoogleCloudRetailV2SearchResponseConversationalSearchResultSuggestedAnswer>
The answer options provided to client for the follow-up question.
Corresponds to the JSON property suggestedAnswers
6459 6460 6461 |
# File 'lib/google/apis/retail_v2/classes.rb', line 6459 def suggested_answers @suggested_answers end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6466 6467 6468 6469 6470 6471 6472 6473 |
# File 'lib/google/apis/retail_v2/classes.rb', line 6466 def update!(**args) @additional_filter = args[:additional_filter] if args.key?(:additional_filter) @additional_filters = args[:additional_filters] if args.key?(:additional_filters) @conversation_id = args[:conversation_id] if args.key?(:conversation_id) @followup_question = args[:followup_question] if args.key?(:followup_question) @refined_query = args[:refined_query] if args.key?(:refined_query) @suggested_answers = args[:suggested_answers] if args.key?(:suggested_answers) end |