Class: Google::Apis::RetailV2::GoogleCloudRetailV2alphaExportAnalyticsMetricsResponse
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2::GoogleCloudRetailV2alphaExportAnalyticsMetricsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb
Overview
Response of the ExportAnalyticsMetricsRequest. If the long running operation was successful, then this message is returned by the google.longrunning. Operations.response field if the operation was successful.
Instance Attribute Summary collapse
-
#error_samples ⇒ Array<Google::Apis::RetailV2::GoogleRpcStatus>
A sample of errors encountered while processing the request.
-
#errors_config ⇒ Google::Apis::RetailV2::GoogleCloudRetailV2alphaExportErrorsConfig
Configuration of destination for Export related errors.
-
#output_result ⇒ Google::Apis::RetailV2::GoogleCloudRetailV2alphaOutputResult
Output result that stores the information about where the exported data is stored.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2alphaExportAnalyticsMetricsResponse
constructor
A new instance of GoogleCloudRetailV2alphaExportAnalyticsMetricsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2alphaExportAnalyticsMetricsResponse
Returns a new instance of GoogleCloudRetailV2alphaExportAnalyticsMetricsResponse.
7722 7723 7724 |
# File 'lib/google/apis/retail_v2/classes.rb', line 7722 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_samples ⇒ Array<Google::Apis::RetailV2::GoogleRpcStatus>
A sample of errors encountered while processing the request.
Corresponds to the JSON property errorSamples
7709 7710 7711 |
# File 'lib/google/apis/retail_v2/classes.rb', line 7709 def error_samples @error_samples end |
#errors_config ⇒ Google::Apis::RetailV2::GoogleCloudRetailV2alphaExportErrorsConfig
Configuration of destination for Export related errors.
Corresponds to the JSON property errorsConfig
7714 7715 7716 |
# File 'lib/google/apis/retail_v2/classes.rb', line 7714 def errors_config @errors_config end |
#output_result ⇒ Google::Apis::RetailV2::GoogleCloudRetailV2alphaOutputResult
Output result that stores the information about where the exported data is
stored.
Corresponds to the JSON property outputResult
7720 7721 7722 |
# File 'lib/google/apis/retail_v2/classes.rb', line 7720 def output_result @output_result end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7727 7728 7729 7730 7731 |
# File 'lib/google/apis/retail_v2/classes.rb', line 7727 def update!(**args) @error_samples = args[:error_samples] if args.key?(:error_samples) @errors_config = args[:errors_config] if args.key?(:errors_config) @output_result = args[:output_result] if args.key?(:output_result) end |