Class: Google::Apis::RetailV2::GoogleCloudRetailV2alphaExportUserEventsResponse
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2::GoogleCloudRetailV2alphaExportUserEventsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb
Overview
Response of the ExportUserEventsRequest. If the long running operation was successful, then this message is returned by the google.longrunning.Operations. response field if the operation was successful.
Instance Attribute Summary collapse
-
#error_samples ⇒ Array<Google::Apis::RetailV2::GoogleRpcStatus>
A sample of errors encountered while processing the request.
-
#errors_config ⇒ Google::Apis::RetailV2::GoogleCloudRetailV2alphaExportErrorsConfig
Configuration of destination for Export related errors.
-
#output_result ⇒ Google::Apis::RetailV2::GoogleCloudRetailV2alphaOutputResult
Output result that stores the information about where the exported data is stored.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2alphaExportUserEventsResponse
constructor
A new instance of GoogleCloudRetailV2alphaExportUserEventsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2alphaExportUserEventsResponse
Returns a new instance of GoogleCloudRetailV2alphaExportUserEventsResponse.
7839 7840 7841 |
# File 'lib/google/apis/retail_v2/classes.rb', line 7839 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_samples ⇒ Array<Google::Apis::RetailV2::GoogleRpcStatus>
A sample of errors encountered while processing the request.
Corresponds to the JSON property errorSamples
7826 7827 7828 |
# File 'lib/google/apis/retail_v2/classes.rb', line 7826 def error_samples @error_samples end |
#errors_config ⇒ Google::Apis::RetailV2::GoogleCloudRetailV2alphaExportErrorsConfig
Configuration of destination for Export related errors.
Corresponds to the JSON property errorsConfig
7831 7832 7833 |
# File 'lib/google/apis/retail_v2/classes.rb', line 7831 def errors_config @errors_config end |
#output_result ⇒ Google::Apis::RetailV2::GoogleCloudRetailV2alphaOutputResult
Output result that stores the information about where the exported data is
stored.
Corresponds to the JSON property outputResult
7837 7838 7839 |
# File 'lib/google/apis/retail_v2/classes.rb', line 7837 def output_result @output_result end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7844 7845 7846 7847 7848 |
# File 'lib/google/apis/retail_v2/classes.rb', line 7844 def update!(**args) @error_samples = args[:error_samples] if args.key?(:error_samples) @errors_config = args[:errors_config] if args.key?(:errors_config) @output_result = args[:output_result] if args.key?(:output_result) end |