Class: Google::Apis::RetailV2::GoogleCloudRetailV2alphaImportProductsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb

Overview

Response of the ImportProductsRequest. If the long running operation is done, then this message is returned by the google.longrunning.Operations.response field if the operation was successful.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2alphaImportProductsResponse

Returns a new instance of GoogleCloudRetailV2alphaImportProductsResponse.



7987
7988
7989
# File 'lib/google/apis/retail_v2/classes.rb', line 7987

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_samplesArray<Google::Apis::RetailV2::GoogleRpcStatus>

A sample of errors encountered while processing the request. Corresponds to the JSON property errorSamples



7980
7981
7982
# File 'lib/google/apis/retail_v2/classes.rb', line 7980

def error_samples
  @error_samples
end

#errors_configGoogle::Apis::RetailV2::GoogleCloudRetailV2alphaImportErrorsConfig

Configuration of destination for Import related errors. Corresponds to the JSON property errorsConfig



7985
7986
7987
# File 'lib/google/apis/retail_v2/classes.rb', line 7985

def errors_config
  @errors_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7992
7993
7994
7995
# File 'lib/google/apis/retail_v2/classes.rb', line 7992

def update!(**args)
  @error_samples = args[:error_samples] if args.key?(:error_samples)
  @errors_config = args[:errors_config] if args.key?(:errors_config)
end