Class: Google::Apis::RetailV2::GoogleCloudRetailV2alphaImportUserEventsResponse
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2::GoogleCloudRetailV2alphaImportUserEventsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb
Overview
Response of the ImportUserEventsRequest. If the long running operation was successful, then this message is returned by the google.longrunning.Operations. response field if the operation was successful.
Instance Attribute Summary collapse
-
#error_samples ⇒ Array<Google::Apis::RetailV2::GoogleRpcStatus>
A sample of errors encountered while processing the request.
-
#errors_config ⇒ Google::Apis::RetailV2::GoogleCloudRetailV2alphaImportErrorsConfig
Configuration of destination for Import related errors.
-
#import_summary ⇒ Google::Apis::RetailV2::GoogleCloudRetailV2alphaUserEventImportSummary
A summary of import result.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2alphaImportUserEventsResponse
constructor
A new instance of GoogleCloudRetailV2alphaImportUserEventsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2alphaImportUserEventsResponse
Returns a new instance of GoogleCloudRetailV2alphaImportUserEventsResponse.
8019 8020 8021 |
# File 'lib/google/apis/retail_v2/classes.rb', line 8019 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_samples ⇒ Array<Google::Apis::RetailV2::GoogleRpcStatus>
A sample of errors encountered while processing the request.
Corresponds to the JSON property errorSamples
8006 8007 8008 |
# File 'lib/google/apis/retail_v2/classes.rb', line 8006 def error_samples @error_samples end |
#errors_config ⇒ Google::Apis::RetailV2::GoogleCloudRetailV2alphaImportErrorsConfig
Configuration of destination for Import related errors.
Corresponds to the JSON property errorsConfig
8011 8012 8013 |
# File 'lib/google/apis/retail_v2/classes.rb', line 8011 def errors_config @errors_config end |
#import_summary ⇒ Google::Apis::RetailV2::GoogleCloudRetailV2alphaUserEventImportSummary
A summary of import result. The UserEventImportSummary summarizes the import
status for user events.
Corresponds to the JSON property importSummary
8017 8018 8019 |
# File 'lib/google/apis/retail_v2/classes.rb', line 8017 def import_summary @import_summary end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8024 8025 8026 8027 8028 |
# File 'lib/google/apis/retail_v2/classes.rb', line 8024 def update!(**args) @error_samples = args[:error_samples] if args.key?(:error_samples) @errors_config = args[:errors_config] if args.key?(:errors_config) @import_summary = args[:import_summary] if args.key?(:import_summary) end |