Class: Google::Apis::RetailV2::GoogleCloudRetailV2alphaMerchantCenterAccountLink

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb

Overview

Represents a link between a Merchant Center account and a branch. After a link is established, products from the linked Merchant Center account are streamed to the linked branch.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2alphaMerchantCenterAccountLink

Returns a new instance of GoogleCloudRetailV2alphaMerchantCenterAccountLink.



8107
8108
8109
# File 'lib/google/apis/retail_v2/classes.rb', line 8107

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#branch_idString

Required. The branch ID (e.g. 0/1/2) within the catalog that products from merchant_center_account_id are streamed to. When updating this field, an empty value will use the currently configured default branch. However, changing the default branch later on won't change the linked branch here. A single branch ID can only have one linked Merchant Center account ID. Corresponds to the JSON property branchId

Returns:

  • (String)


8044
8045
8046
# File 'lib/google/apis/retail_v2/classes.rb', line 8044

def branch_id
  @branch_id
end

#feed_filtersArray<Google::Apis::RetailV2::GoogleCloudRetailV2alphaMerchantCenterAccountLinkMerchantCenterFeedFilter>

Criteria for the Merchant Center feeds to be ingested via the link. All offers will be ingested if the list is empty. Otherwise the offers will be ingested from selected feeds. Corresponds to the JSON property feedFilters



8051
8052
8053
# File 'lib/google/apis/retail_v2/classes.rb', line 8051

def feed_filters
  @feed_filters
end

#feed_labelString

The FeedLabel used to perform filtering. Note: this replaces region_id. Example value: US. Example value: FeedLabel1. Corresponds to the JSON property feedLabel

Returns:

  • (String)


8058
8059
8060
# File 'lib/google/apis/retail_v2/classes.rb', line 8058

def feed_label
  @feed_label
end

#idString

Output only. Immutable. MerchantCenterAccountLink identifier, which is the final component of name. This field is auto generated and follows the convention: BranchId_MerchantCenterAccountId. projects/*/locations/global/ catalogs/default_catalog/merchantCenterAccountLinks/id_1. Corresponds to the JSON property id

Returns:

  • (String)


8066
8067
8068
# File 'lib/google/apis/retail_v2/classes.rb', line 8066

def id
  @id
end

#language_codeString

Language of the title/description and other string attributes. Use language tags defined by BCP 47. ISO 639-1. This specifies the language of offers in Merchant Center that will be accepted. If empty, no language filtering will be performed. Example value: en. Corresponds to the JSON property languageCode

Returns:

  • (String)


8075
8076
8077
# File 'lib/google/apis/retail_v2/classes.rb', line 8075

def language_code
  @language_code
end

#merchant_center_account_idFixnum

Required. The linked Merchant center account id. The account must be a standalone account or a sub-account of a MCA. Corresponds to the JSON property merchantCenterAccountId

Returns:

  • (Fixnum)


8082
8083
8084
# File 'lib/google/apis/retail_v2/classes.rb', line 8082

def 
  @merchant_center_account_id
end

#nameString

Output only. Immutable. Full resource name of the Merchant Center Account Link, such as projects/*/locations/global/catalogs/default_catalog/ merchantCenterAccountLinks/merchant_center_account_link. Corresponds to the JSON property name

Returns:

  • (String)


8089
8090
8091
# File 'lib/google/apis/retail_v2/classes.rb', line 8089

def name
  @name
end

#project_idString

Output only. Google Cloud project ID. Corresponds to the JSON property projectId

Returns:

  • (String)


8094
8095
8096
# File 'lib/google/apis/retail_v2/classes.rb', line 8094

def project_id
  @project_id
end

#sourceString

Optional. An optional arbitrary string that could be used as a tag for tracking link source. Corresponds to the JSON property source

Returns:

  • (String)


8100
8101
8102
# File 'lib/google/apis/retail_v2/classes.rb', line 8100

def source
  @source
end

#stateString

Output only. Represents the state of the link. Corresponds to the JSON property state

Returns:

  • (String)


8105
8106
8107
# File 'lib/google/apis/retail_v2/classes.rb', line 8105

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8112
8113
8114
8115
8116
8117
8118
8119
8120
8121
8122
8123
# File 'lib/google/apis/retail_v2/classes.rb', line 8112

def update!(**args)
  @branch_id = args[:branch_id] if args.key?(:branch_id)
  @feed_filters = args[:feed_filters] if args.key?(:feed_filters)
  @feed_label = args[:feed_label] if args.key?(:feed_label)
  @id = args[:id] if args.key?(:id)
  @language_code = args[:language_code] if args.key?(:language_code)
  @merchant_center_account_id = args[:merchant_center_account_id] if args.key?(:merchant_center_account_id)
  @name = args[:name] if args.key?(:name)
  @project_id = args[:project_id] if args.key?(:project_id)
  @source = args[:source] if args.key?(:source)
  @state = args[:state] if args.key?(:state)
end