Class: Google::Apis::RetailV2::GoogleCloudRetailV2alphaModel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb

Overview

Metadata that describes the training and serving parameters of a Model. A Model can be associated with a ServingConfig and then queried through the Predict API.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2alphaModel

Returns a new instance of GoogleCloudRetailV2alphaModel.



8288
8289
8290
# File 'lib/google/apis/retail_v2/classes.rb', line 8288

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp the Recommendation Model was created at. Corresponds to the JSON property createTime

Returns:

  • (String)


8168
8169
8170
# File 'lib/google/apis/retail_v2/classes.rb', line 8168

def create_time
  @create_time
end

#data_stateString

Output only. The state of data requirements for this model: DATA_OK and DATA_ERROR. Recommendation model cannot be trained if the data is in DATA_ERROR state. Recommendation model can have DATA_ERROR state even if serving state is ACTIVE: models were trained successfully before, but cannot be refreshed because model no longer has sufficient data for training. Corresponds to the JSON property dataState

Returns:

  • (String)


8177
8178
8179
# File 'lib/google/apis/retail_v2/classes.rb', line 8177

def data_state
  @data_state
end

#display_nameString

Required. The display name of the model. Should be human readable, used to display Recommendation Models in the Retail Cloud Console Dashboard. UTF-8 encoded string with limit of 1024 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


8184
8185
8186
# File 'lib/google/apis/retail_v2/classes.rb', line 8184

def display_name
  @display_name
end

#filtering_optionString

Optional. If RECOMMENDATIONS_FILTERING_ENABLED, recommendation filtering by attributes is enabled for the model. Corresponds to the JSON property filteringOption

Returns:

  • (String)


8190
8191
8192
# File 'lib/google/apis/retail_v2/classes.rb', line 8190

def filtering_option
  @filtering_option
end

#last_tune_timeString

Output only. The timestamp when the latest successful tune finished. Corresponds to the JSON property lastTuneTime

Returns:

  • (String)


8195
8196
8197
# File 'lib/google/apis/retail_v2/classes.rb', line 8195

def last_tune_time
  @last_tune_time
end

#model_features_configGoogle::Apis::RetailV2::GoogleCloudRetailV2alphaModelModelFeaturesConfig

Additional model features config. Corresponds to the JSON property modelFeaturesConfig



8200
8201
8202
# File 'lib/google/apis/retail_v2/classes.rb', line 8200

def model_features_config
  @model_features_config
end

#nameString

Required. The fully qualified resource name of the model. Format: projects/ project_number/locations/location_id/catalogs/catalog_id/models/model_id catalog_id has char limit of 50. recommendation_model_id has char limit of 40. Corresponds to the JSON property name

Returns:

  • (String)


8208
8209
8210
# File 'lib/google/apis/retail_v2/classes.rb', line 8208

def name
  @name
end

#optimization_objectiveString

Optional. The optimization objective e.g. cvr. Currently supported values: ctr, cvr, revenue-per-order. If not specified, we choose default based on model type. Default depends on type of recommendation: recommended-for-you => ctr others-you-may-like => ctr frequently-bought-together => revenue_per_order This field together with optimization_objective describe model metadata to use to control model training and serving. See https://cloud. google.com/retail/docs/models for more details on what the model metadata control and which combination of parameters are valid. For invalid combinations of parameters (e.g. type = frequently-bought-together and optimization_objective = ctr), you receive an error 400 if you try to create/ update a recommendation with this set of knobs. Corresponds to the JSON property optimizationObjective

Returns:

  • (String)


8223
8224
8225
# File 'lib/google/apis/retail_v2/classes.rb', line 8223

def optimization_objective
  @optimization_objective
end

#page_optimization_configGoogle::Apis::RetailV2::GoogleCloudRetailV2alphaModelPageOptimizationConfig

The PageOptimizationConfig for model training. This determines how many panels to optimize for, and which serving configs to consider for each panel. The purpose of this model is to optimize which ServingConfig to show on which panels in way that optimizes the visitors shopping journey. Corresponds to the JSON property pageOptimizationConfig



8231
8232
8233
# File 'lib/google/apis/retail_v2/classes.rb', line 8231

def page_optimization_config
  @page_optimization_config
end

#periodic_tuning_stateString

Optional. The state of periodic tuning. The period we use is 3 months - to do a one-off tune earlier use the TuneModel method. Default value is PERIODIC_TUNING_ENABLED. Corresponds to the JSON property periodicTuningState

Returns:

  • (String)


8238
8239
8240
# File 'lib/google/apis/retail_v2/classes.rb', line 8238

def periodic_tuning_state
  @periodic_tuning_state
end

#serving_config_listsArray<Google::Apis::RetailV2::GoogleCloudRetailV2alphaModelServingConfigList>

Output only. The list of valid serving configs associated with the PageOptimizationConfig. Corresponds to the JSON property servingConfigLists



8244
8245
8246
# File 'lib/google/apis/retail_v2/classes.rb', line 8244

def serving_config_lists
  @serving_config_lists
end

#serving_stateString

Output only. The serving state of the model: ACTIVE, NOT_ACTIVE. Corresponds to the JSON property servingState

Returns:

  • (String)


8249
8250
8251
# File 'lib/google/apis/retail_v2/classes.rb', line 8249

def serving_state
  @serving_state
end

#training_stateString

Optional. The training state that the model is in (e.g. TRAINING or PAUSED) . Since part of the cost of running the service is frequency of training - this can be used to determine when to train model in order to control cost. If not specified: the default value for CreateModel method is TRAINING. The default value for UpdateModel method is to keep the state the same as before. Corresponds to the JSON property trainingState

Returns:

  • (String)


8258
8259
8260
# File 'lib/google/apis/retail_v2/classes.rb', line 8258

def training_state
  @training_state
end

#tuning_operationString

Output only. The tune operation associated with the model. Can be used to determine if there is an ongoing tune for this recommendation. Empty field implies no tune is goig on. Corresponds to the JSON property tuningOperation

Returns:

  • (String)


8265
8266
8267
# File 'lib/google/apis/retail_v2/classes.rb', line 8265

def tuning_operation
  @tuning_operation
end

#typeString

Required. The type of model e.g. home-page. Currently supported values: recommended-for-you, others-you-may-like, frequently-bought-together, page-optimization, similar-items, buy-it-again, on-sale-items, and recently-viewed(readonly value). This field together with optimization_objective describe model metadata to use to control model training and serving. See https://cloud.google.com/retail/docs/models for more details on what the model metadata control and which combination of parameters are valid. For invalid combinations of parameters (e.g. type = frequently- bought-together and optimization_objective = ctr), you receive an error 400 if you try to create/update a recommendation with this set of knobs. Corresponds to the JSON property type

Returns:

  • (String)


8279
8280
8281
# File 'lib/google/apis/retail_v2/classes.rb', line 8279

def type
  @type
end

#update_timeString

Output only. Timestamp the Recommendation Model was last updated. E.g. if a Recommendation Model was paused - this would be the time the pause was initiated. Corresponds to the JSON property updateTime

Returns:

  • (String)


8286
8287
8288
# File 'lib/google/apis/retail_v2/classes.rb', line 8286

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8293
8294
8295
8296
8297
8298
8299
8300
8301
8302
8303
8304
8305
8306
8307
8308
8309
8310
# File 'lib/google/apis/retail_v2/classes.rb', line 8293

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_state = args[:data_state] if args.key?(:data_state)
  @display_name = args[:display_name] if args.key?(:display_name)
  @filtering_option = args[:filtering_option] if args.key?(:filtering_option)
  @last_tune_time = args[:last_tune_time] if args.key?(:last_tune_time)
  @model_features_config = args[:model_features_config] if args.key?(:model_features_config)
  @name = args[:name] if args.key?(:name)
  @optimization_objective = args[:optimization_objective] if args.key?(:optimization_objective)
  @page_optimization_config = args[:page_optimization_config] if args.key?(:page_optimization_config)
  @periodic_tuning_state = args[:periodic_tuning_state] if args.key?(:periodic_tuning_state)
  @serving_config_lists = args[:serving_config_lists] if args.key?(:serving_config_lists)
  @serving_state = args[:serving_state] if args.key?(:serving_state)
  @training_state = args[:training_state] if args.key?(:training_state)
  @tuning_operation = args[:tuning_operation] if args.key?(:tuning_operation)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
end