Class: Google::Apis::RetailV2::GoogleCloudRetailV2alphaTransformedUserEventsMetadata
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2::GoogleCloudRetailV2alphaTransformedUserEventsMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb
Overview
Metadata related to transform user events operation.
Instance Attribute Summary collapse
-
#source_events_count ⇒ Fixnum
Count of entries in the source user events BigQuery table.
-
#transformed_events_count ⇒ Fixnum
Count of entries in the transformed user events BigQuery table, which could be different from the actually imported number of user events.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2alphaTransformedUserEventsMetadata
constructor
A new instance of GoogleCloudRetailV2alphaTransformedUserEventsMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2alphaTransformedUserEventsMetadata
Returns a new instance of GoogleCloudRetailV2alphaTransformedUserEventsMetadata.
8736 8737 8738 |
# File 'lib/google/apis/retail_v2/classes.rb', line 8736 def initialize(**args) update!(**args) end |
Instance Attribute Details
#source_events_count ⇒ Fixnum
Count of entries in the source user events BigQuery table.
Corresponds to the JSON property sourceEventsCount
8728 8729 8730 |
# File 'lib/google/apis/retail_v2/classes.rb', line 8728 def source_events_count @source_events_count end |
#transformed_events_count ⇒ Fixnum
Count of entries in the transformed user events BigQuery table, which could be
different from the actually imported number of user events.
Corresponds to the JSON property transformedEventsCount
8734 8735 8736 |
# File 'lib/google/apis/retail_v2/classes.rb', line 8734 def transformed_events_count @transformed_events_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8741 8742 8743 8744 |
# File 'lib/google/apis/retail_v2/classes.rb', line 8741 def update!(**args) @source_events_count = args[:source_events_count] if args.key?(:source_events_count) @transformed_events_count = args[:transformed_events_count] if args.key?(:transformed_events_count) end |