Class: Google::Apis::RetailV2::GoogleCloudRetailV2betaExportAnalyticsMetricsResponse
- Inherits:
-
Object
- Object
- Google::Apis::RetailV2::GoogleCloudRetailV2betaExportAnalyticsMetricsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb
Overview
Response of the ExportAnalyticsMetricsRequest. If the long running operation was successful, then this message is returned by the google.longrunning. Operations.response field if the operation was successful.
Instance Attribute Summary collapse
-
#error_samples ⇒ Array<Google::Apis::RetailV2::GoogleRpcStatus>
A sample of errors encountered while processing the request.
-
#errors_config ⇒ Google::Apis::RetailV2::GoogleCloudRetailV2betaExportErrorsConfig
Configuration of destination for Export related errors.
-
#output_result ⇒ Google::Apis::RetailV2::GoogleCloudRetailV2betaOutputResult
Output result that stores the information about where the exported data is stored.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRetailV2betaExportAnalyticsMetricsResponse
constructor
A new instance of GoogleCloudRetailV2betaExportAnalyticsMetricsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRetailV2betaExportAnalyticsMetricsResponse
Returns a new instance of GoogleCloudRetailV2betaExportAnalyticsMetricsResponse.
8937 8938 8939 |
# File 'lib/google/apis/retail_v2/classes.rb', line 8937 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_samples ⇒ Array<Google::Apis::RetailV2::GoogleRpcStatus>
A sample of errors encountered while processing the request.
Corresponds to the JSON property errorSamples
8924 8925 8926 |
# File 'lib/google/apis/retail_v2/classes.rb', line 8924 def error_samples @error_samples end |
#errors_config ⇒ Google::Apis::RetailV2::GoogleCloudRetailV2betaExportErrorsConfig
Configuration of destination for Export related errors.
Corresponds to the JSON property errorsConfig
8929 8930 8931 |
# File 'lib/google/apis/retail_v2/classes.rb', line 8929 def errors_config @errors_config end |
#output_result ⇒ Google::Apis::RetailV2::GoogleCloudRetailV2betaOutputResult
Output result that stores the information about where the exported data is
stored.
Corresponds to the JSON property outputResult
8935 8936 8937 |
# File 'lib/google/apis/retail_v2/classes.rb', line 8935 def output_result @output_result end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8942 8943 8944 8945 8946 |
# File 'lib/google/apis/retail_v2/classes.rb', line 8942 def update!(**args) @error_samples = args[:error_samples] if args.key?(:error_samples) @errors_config = args[:errors_config] if args.key?(:errors_config) @output_result = args[:output_result] if args.key?(:output_result) end |