Class: Google::Apis::RetailV2::GoogleCloudRetailV2betaExportProductsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb

Overview

Response of the ExportProductsRequest. If the long running operation is done, then this message is returned by the google.longrunning.Operations.response field if the operation was successful.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2betaExportProductsResponse

Returns a new instance of GoogleCloudRetailV2betaExportProductsResponse.



9018
9019
9020
# File 'lib/google/apis/retail_v2/classes.rb', line 9018

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_samplesArray<Google::Apis::RetailV2::GoogleRpcStatus>

A sample of errors encountered while processing the request. Corresponds to the JSON property errorSamples



9005
9006
9007
# File 'lib/google/apis/retail_v2/classes.rb', line 9005

def error_samples
  @error_samples
end

#errors_configGoogle::Apis::RetailV2::GoogleCloudRetailV2betaExportErrorsConfig

Configuration of destination for Export related errors. Corresponds to the JSON property errorsConfig



9010
9011
9012
# File 'lib/google/apis/retail_v2/classes.rb', line 9010

def errors_config
  @errors_config
end

#output_resultGoogle::Apis::RetailV2::GoogleCloudRetailV2betaOutputResult

Output result that stores the information about where the exported data is stored. Corresponds to the JSON property outputResult



9016
9017
9018
# File 'lib/google/apis/retail_v2/classes.rb', line 9016

def output_result
  @output_result
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9023
9024
9025
9026
9027
# File 'lib/google/apis/retail_v2/classes.rb', line 9023

def update!(**args)
  @error_samples = args[:error_samples] if args.key?(:error_samples)
  @errors_config = args[:errors_config] if args.key?(:errors_config)
  @output_result = args[:output_result] if args.key?(:output_result)
end