Class: Google::Apis::RetailV2::GoogleCloudRetailV2betaImportCompletionDataResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb

Overview

Response of the ImportCompletionDataRequest. If the long running operation is done, this message is returned by the google.longrunning.Operations.response field if the operation is successful.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2betaImportCompletionDataResponse

Returns a new instance of GoogleCloudRetailV2betaImportCompletionDataResponse.



9094
9095
9096
# File 'lib/google/apis/retail_v2/classes.rb', line 9094

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_samplesArray<Google::Apis::RetailV2::GoogleRpcStatus>

A sample of errors encountered while processing the request. Corresponds to the JSON property errorSamples



9092
9093
9094
# File 'lib/google/apis/retail_v2/classes.rb', line 9092

def error_samples
  @error_samples
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9099
9100
9101
# File 'lib/google/apis/retail_v2/classes.rb', line 9099

def update!(**args)
  @error_samples = args[:error_samples] if args.key?(:error_samples)
end