Class: Google::Apis::RetailV2::GoogleCloudRetailV2betaImportProductsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb

Overview

Response of the ImportProductsRequest. If the long running operation is done, then this message is returned by the google.longrunning.Operations.response field if the operation was successful.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2betaImportProductsResponse

Returns a new instance of GoogleCloudRetailV2betaImportProductsResponse.



9195
9196
9197
# File 'lib/google/apis/retail_v2/classes.rb', line 9195

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_samplesArray<Google::Apis::RetailV2::GoogleRpcStatus>

A sample of errors encountered while processing the request. Corresponds to the JSON property errorSamples



9188
9189
9190
# File 'lib/google/apis/retail_v2/classes.rb', line 9188

def error_samples
  @error_samples
end

#errors_configGoogle::Apis::RetailV2::GoogleCloudRetailV2betaImportErrorsConfig

Configuration of destination for Import related errors. Corresponds to the JSON property errorsConfig



9193
9194
9195
# File 'lib/google/apis/retail_v2/classes.rb', line 9193

def errors_config
  @errors_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9200
9201
9202
9203
# File 'lib/google/apis/retail_v2/classes.rb', line 9200

def update!(**args)
  @error_samples = args[:error_samples] if args.key?(:error_samples)
  @errors_config = args[:errors_config] if args.key?(:errors_config)
end