Class: Google::Apis::RetailV2::GoogleCloudRetailV2betaOutputResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb

Overview

Output result that stores the information about where the exported data is stored.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2betaOutputResult

Returns a new instance of GoogleCloudRetailV2betaOutputResult.



9461
9462
9463
# File 'lib/google/apis/retail_v2/classes.rb', line 9461

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bigquery_resultArray<Google::Apis::RetailV2::GoogleCloudRetailV2betaBigQueryOutputResult>

The BigQuery location where the result is stored. Corresponds to the JSON property bigqueryResult



9454
9455
9456
# File 'lib/google/apis/retail_v2/classes.rb', line 9454

def bigquery_result
  @bigquery_result
end

#gcs_resultArray<Google::Apis::RetailV2::GoogleCloudRetailV2betaGcsOutputResult>

The Google Cloud Storage location where the result is stored. Corresponds to the JSON property gcsResult



9459
9460
9461
# File 'lib/google/apis/retail_v2/classes.rb', line 9459

def gcs_result
  @gcs_result
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9466
9467
9468
9469
# File 'lib/google/apis/retail_v2/classes.rb', line 9466

def update!(**args)
  @bigquery_result = args[:bigquery_result] if args.key?(:bigquery_result)
  @gcs_result = args[:gcs_result] if args.key?(:gcs_result)
end