Class: Google::Apis::RetailV2::GoogleCloudRetailV2betaPurgeUserEventsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/retail_v2/classes.rb,
lib/google/apis/retail_v2/representations.rb,
lib/google/apis/retail_v2/representations.rb

Overview

Response of the PurgeUserEventsRequest. If the long running operation is successfully done, then this message is returned by the google.longrunning. Operations.response field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRetailV2betaPurgeUserEventsResponse

Returns a new instance of GoogleCloudRetailV2betaPurgeUserEventsResponse.



9565
9566
9567
# File 'lib/google/apis/retail_v2/classes.rb', line 9565

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#purged_events_countFixnum

The total count of events purged as a result of the operation. Corresponds to the JSON property purgedEventsCount

Returns:

  • (Fixnum)


9563
9564
9565
# File 'lib/google/apis/retail_v2/classes.rb', line 9563

def purged_events_count
  @purged_events_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9570
9571
9572
# File 'lib/google/apis/retail_v2/classes.rb', line 9570

def update!(**args)
  @purged_events_count = args[:purged_events_count] if args.key?(:purged_events_count)
end